
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python FinTech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']


def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    pass


class SWIFTParserError:
    """
    SWIFT parser returned an error.
    """
    pass



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\xf3$\x00\x00\x00\x97\x00d\x00d\x01l\x00m\x01Z\x01\x01\x00\x02\x00e\x01e\x02e\x03d\x02\xab\x03\x00\x00\x00\x00\x00\x00\x01\x00y\x03)\x04'
        b'\xe9\x01\x00\x00\x00)\x01\xda\x0b__pyarmor__s\x83K\x00\x00PY004022\x00\x03\x0c\x00\xcb\r\r\n\x80\x00\x01\x00\x08\x00\x00\x00\x04\x00\x00\x00@\x00\x00\x00CK\x00\x002\t\x05'
        b'\x00\xe0\x87\xfc\xac#Pb\xb9f\x07\xb2Aed\xa5\xb1\x00\x00\x00\x00\x00\x00\x00\x00\xcc|\x95\x05\x95I\xec+\xdab\x1d\xc4B\x84{\xbe\x02m\x8e\xba\x8d\xb2\x94\x1c\xe2.\xc4\xc7\xb5{\x88\x15\xa1z\x03\xa8\xe7c&'
        b'z\x8c\xfeP\x14\r\x94\xf2\xa3u\x17z<\x89\x96\xbe\xa4@\xc0\x8b\x81$My5\xb9\xa1&\xf1\xa9}\xd4\xc0\xe2\xd7\xd9\xea\xc6\xc6\xae\x12\xd9\x03\xcaF\xae\x8d\xbeb\r\xb45"\x82h\xf20ar\x13\xe29\x03y'
        b'\x1e\xa3\x83\x9de)5\xe7FPL\x99\x97\xad\xf1C\x88\xf2`,\xc4\xdcghZ\x93\xbb\x13"\xc1\xb5\x9d!\x97m\xbbB\xae\xb62V\xf1\xf45\xa8\xc5nWk\xed\xfa\x99r\x88\x1fW\x87\x98\x18d}\xab\xf2\xf2'
        b'\xc4\xcb\xc84\x15\xf8\x04\xb9%\x19\x1b\xc8x\xa2\xa3_\xb4\x87;}\xf3G-\xa0\x1a\xd8j\x0fv\xea\x16W\x07\x81\xd6K\x98\xcaJ\xef\xcfQ\xac\x86\xcd~\x9fe\x92\x16Xm\xc1\xbb~A$TT\xed\x88\xd4\xc5U'
        b'\xdfb\x0f\xf1\'\x9b\x12\xcc\x92\xdd7^\xc3\xea\xd8\xaa\xb7\xa4\x94\xc4\xfbDo\xaf\xd6?\xe4\xd1\xbf\xb3\xd0k\\\xde\x00?\xc4\x1a# \xe3\x0f"\xd9\xa0Y#I\xc3\x93cc\xd0\xae$ \xab\xedf\x12\x94~\xe1\xde'
        b'\x9c\xf1\xdd1S\xb8\xc1\xa1\\\xe61Q\xdb\xe3\xcc\xeb\xfc\xff^\xe4MD\x0b\x865\x1c\xceF\x9b\xe0\xf1(\x84H\x9f\xd4\xd0\x88 \x84r\xef\xab\x9d\xf3p,\xdeK-\x04\xac\x8fNm\x01\x1d\x9c\x96\x0f^\xd7\x18^'
        b'\xd1<\xad:\xb0\xe3\x19\x81;Hf\\m\x8aa\xa0\t\xe6\xccMD^\x1c\x9b\xf7\xc0x\x8d\xc5\x8aO\xe0\x87\xcd\xebf\x1b\xbe<\x8b\x1c/Qq\x9c\x9d\x12QbtS\xe1\xa4\x83\xdea\x16\xa3s\xfc\xc4\xbdS\xd2'
        b'$\x0e^\x98\xda\xb8E\x11\x1e\x18\xa3\xee\xe6\xb3u\xd7\xc8}#\xf2\x03\xba\xed\xfc\xda\x80\x91\xdd\xae\x8c\x80G\x19\xe4O\x97\x1e\xdcxQL\xfa\xf6S\xf9\xa8\x97\x9ch\xc39\xe8\x1fi\xb3\x04\x95z\xab\x83\xe1b\xceP'
        b'\xd1m\xcb\xbb\x16\xe3J#\x98=R\x83f\x00a\xf2;\x13^w\xb7&%?\xd3\xb4\x90\x08T)\xa1\xdb\x91oh\x07s\x8b\xf4\xeeG\x11\xe5\x9f4\x81\x85\x1e\xf8Vf\xc9\xa6-\xba\xb0\x9f,\x1e;\x9bP\xd5\xda'
        b'\x1b\xdc6\xcc\xc2\xc2\x83\xdb\xff\xdf\xd3\x8f\xb1=e\x1aK\x05E\\\xa6\xc4/!L\xea\xa2)\xe8\t\xfcZ\xab\xfc,{&\xf3\xde\xc7l\x83\xb5t\xcc\xb6\x0b\xea\xdb\xc9\xcd\x9a\x93i\xb4\xcfb\xa6\xd3q*t\xa0z'
        b"\xac?0\x00\x94$\xf8'R\x85k\xd8(\x97%\x03m\xebM:e1\xeb\x81)'\xf9\xbb\xac\xf0E\xf9\xabt\xc5\xb1\x10\x10teL\xce\xd7\xfb\xdd\xc0\x18\x92\x8a\xde\xe3\x14\xbaa\xe6\xbb\xe4\x9d`\xa2p\x0b\x98\n"
        b'\x80n(~\xbeG\x95\xfcv9["\x98\x04:\xd1\xe0\xbc\x0c6\xe1\xba\x8c\x15Y\xeaG\xec\x11*\xa2\xfc\xd76nL\xb3t\x07\xac\xed3\xd0v\xf6Tnu\xb3u\xf4\xee\n\x1ah\xa8\x8e\x08\x84\xf7\xb9$\x84\xbd'
        b'\xee\xb0E\xaaV15\xc5\x97\x94\x9fNXt \x94a\x8d\x1b\xc8U\xb4\xe8,\xbe\xfb\x1d\xb0\xb5\xd2\x93\xef\xc6f\x92.\xc9\xeaA\x93\xff\x13\xa5K\x9c\x00\xca\xfb\x8b%\xbah\x01\x175\x06\xed\x16jJ\xb51$\x14'
        b"\x03w.r\x82\xa6\xbf\xee!\xc4\xa4+r\xd80\x00\xc4\xca\x0f'\x89Vf\xd9\xbdor\xd5\xb3\x19\xe3\xda\x0b\x19\x00L\xc0>\xe2\xc3*Q\x9d\xee\x7f\x0c:\x03\x87\xf7\x8c\xa7\x92=8V:\x15\x0c\xad\xb5\xa9's"
        b'\x1f\x89\x11\xe4\x10!\xb1_\x87?\x0c\xab\x81\xa0Z\r\xef\xb4MF\xb1\xdc\x0e7\xbcN\xa6\x0c\xa3\x01\xdf\xc6\x9e\xcf\xab\x0c4\xa1\xe4\x9b\xa3\xb6\xef\xdc\xf5\xf9y@B\xd9>\xe3iJ\xff\xf9\x0f\xf5\x82\x7f\x82\xfav\xfc'
        b"\x95x;\x14\x14\xe5$9\xa6e\xbdd{F'P\x08CF\xdcQ\x91\n7\xb32\xeb\x9e3h\x089D\x8a\xbc|s\xcfq\x83\xbd\x88\xa8L\x0e\xc5_\xa4S\xc5e\xeeL\xc5\xf7\xb4~\xce\xdd\xc6v)\xac\xa9"
        b'\xd2\xbe+\xbf\xd0\xfamW\x11\xb1\xc8q\xde\xf1\xcd\xdb\x87\x7f\x00bF\x847\xf9%\xe0b\x1f\xbd\xb9`)\xaa=d\x18\xc8hE\x84\x10\x10\x93\x90`\xe2\xfeKk\x95\xf8_\x9d\xe2\xf7\xed\xd40Z\xeau\xc6\x1b\xaf'
        b'\xe1\x9fV^\x96\xefz\xda\x1b\x11%J\xb1f\x13\xf4\xe2\xe7\xbc\x18\xb6\xbb\x02o\xba-W\x88\xf8\xac\xf6\xae{\xd3\x03{\xc7E\x19\x05\xd8\xc7\xa0!\xd81\xb7\xe82\xe5\xaa\xfb\x8aj\x13\xe2\xa4\x19#`\x17\xbd\x0e-'
        b'\xe9\xa4\xfb^\xd9\x9a\xb9mT\xdd\xd4\xda\xe9\xa2\xab\xa8\xa1T\x19\xc5e\xa5\xb9\x040\xf9\xb3\x91sV\t.\x9d\x8bM\xb8\xae+/6\xa3\x1cd\xa4f\xd4+=\xc6\x7f\xd1\xc1}t\xd8y\x18OWA\xce\xea\xbb\xb5'
        b'\xdd\x99\xa8\xde\xea\x90(\x9b\xbeF}\xda\xad\xc4\xda\xda^\xcd\xb2\x18\xfe\x99yz\xaf\x06\xa5\xc3\xcf\xf7\x85\x80\xdf\x86\xc99*9&\xb5\xda\xad\xdb\xaa\xcb\x8f\xfd\xf9\x1bID\x83SZeZ\xdc\xae!^S\xd2\xe8f'
        b'm\xb5\xf6g\x88\x19_\x15\x80\x8b]\xcb#\xd3\x14\x1d\x11|IE\xd8\x86\xa1\xdb*\xd3N\x0f\x0f\xa5h\xb6N\xdd\xdfW\xd9_\xd2\x81\xba\xd8\x87\xb4\rl\xe8\xe5\xa0\xdf\x18\xd3\x0cD\xcb1\x1e\\\xd8\xf6\xa3\x7f\x1e\xc5'
        b';2\x1f\xbb\xf91\x97\x86\xcb\xefk\xbae\x8e\x8e2\x82Y\x1eV"\x94\xb8\xe3W.\x1a\x0c)\xa3\xb5eMV\x87\xd5\xcc\xe7\x11\xa4]\xdaO1\xa5\x14\xf2.(|\x1e\xe3;\xd5\x11]yM\xfb\x03\x18Y\x192'
        b'\x19\x9e\xf8H&0&P\xb8-\xeb\xcdj$@\x88\x84AX\x06\xd8\xf4K\x19u+\xed\x06\xe3`\xf2.\xd3\x89\x87\nv\xe3\xb5\x88\xc9\x97s\x17g[\x99\xdanz\x07hM\x18\x95l\xbb\xee\xf6\xf9:@\xdc\xc9'
        b"\xe87\x7f\xe8\xd7V\xa8R\n\xa0n\xcbNw\xd2\xa0+\xeb\x1d\xf7\x99o|\x8e\xb7\xd0m\xca\xaa'\x00\x00[\x0b\xcc6m=\xe2\x8e\xd8O4w}\xf6\xc9\x05\x9b\xbd\xa0\x03\xcf\xaf\xdd1_\xed\x03\x1b\x15\x82\xed\xed"
        b'\x87\x19\xe2\x9a\x01\x9e\xd05\xcb;$S\xaf6\xa8\xd8\x03\xd6o\xd7\x9b\xa9,!\xce\x8b5%%\xfc\xc0N\xbft1\xb3\x04l\xc9W\xf1\tf\xc99\xa7\xc4)\xb6C|\x8b\xf4\xab\xd8\xe0\xbb\xdf;m\x03\x86\x9a '
        b'\xc7;\xf6/xs\x15\x13\x89\xde\xa2`;[\xb9\x13Y\xe8\xa78\x0e\xde0.F3b\xa0gk\xe4\x7f\xfd+\x160(\x8c\x99?\x17?\x82\xb8\x13\xbbK\x9f\xf7\xb5\xef\xa3\xa0\xc8Hz6.!\xc6\xef\xdfr\x07'
        b'\xeb\xe2\xdc\x93\xaa\xdf \x8a\xba$@\xb2\xd8Q\xaf;\xc7\xc6\x8f\xd0\xa5\xa5\xa3R\xa4\x18\xa9\x07=\xd8\x1cGj\xbf\xfcP\x94\x19\x81\xdc\xb6<\xfb\x955\xaf,(4\xe9\x00\x1fi\\\xa1\xc7\x0b4%D\xa0\xa1|\x02'
        b'\xb6\xdc\x1bQ-\xabW\xec\x10\x17\x9bL\x14\xb9,\xb5\x9b\xf3uq\x9c8~\xe0]\x08\xe6\x89\xd7zk\xd4{6\xda\x054\xfa\x12\x8a\xc5\xea\x98\x155\xc4\x0c2\xbd<\x0cB\xb3\x05\xe1\x15\x13\xab\x0f\x8e\xe9v\x94 '
        b'$;\xceoFE\x9b;N\xaa\x08\xf0\x07\xebK X\x8d|\xdc\xe5\x88Je9N\xa6\xfc\xf7\xdcu\xa1=:HE\x85\x9b\xe4(\x7f\xb3\xdf\x14\x0e\xdb\xd8\xfbk\xdf\x94\nM\xce\x84)\n\x04a\x157T\x1a\x82'
        b'\xe6\xaf\xb9\xe7\x8c\x9f)\xbb\xe5\x15\xa2v\x14\xd3\x1eVO\x89\x1b\xf4\x82"\x82Va\x9d\x96\xadBzC\xc0\x84^P\xcaw?\xad\x1c\x95o6c\xbeg\x13\xcd\xd0h\x10\x960`\xeb\x9c\x08\x96\xed\xdc\xba\xfc\xccf'
        b'\x04\xc0\x9ay\x94&\xeb\xfa\x87\x14\\$\xef\xa3`X\xc5{\xf3S\x97sC\xa3&\xde\x85{\xb7\xd4\xafLm\xed\x12a\xa9\xd90%\x96\x96\xf2y\x8b\xe5\xc5\xa6\xfd\x924*U\x1b\xec\xa8\x96\xb61\x1d_xW\xae'
        b'\xc5\xba#\xaabD"y\'w\x02\x88_&\xd7\x020,\x9c&!\x00\x88\x9d\xf6\xb9\x9eW\xcc#y\xc98\x1e\x84Jg\x13\xbe\xd16\xbb\xa6;ny\x84\xa0\x9a/\xea!\x9fg\x83M[\xc4amz\xe9\x9e\xd5'
        b'\xc7h\xb8\x10]\x9a\x07\\\x938Mu\xa1\xd7\x0e\xe2\xa1\x023;\xeb\xfc74z\x95\xa8\xee\xc0\xecY\xa7iE\xd0\xf3.\x0b\x05iR\xa1=\xd8\x08j\xe4\x18\xcbe\x9d\t?\xfc\xa0\xa6=?f\x82\x9c"G\xb1'
        b"\xf4y\xbc\x0c\xd6/\x1f\xeaQ\x15r\x18\x06\xa0\x83\xb6\x1et\x88\x96i\xaa\xf2\xf2\x15\xd6<\xe1,e\xcfv\x1b1\x95\x8fQ\xd8\x86\xe8\x91\xd4\xb6?x\xef\xa3_f'~\x7f&7\xd1\x97\xb9\x08!t!\xe4\x90\x0c"
        b'z\x0e\xe4\xae\xc3z\x93\xb5\xbc,\xc1R\x82 \x96i,on\xf0\xfdh\xca\x8a\x9c\x9d\xa7\x84T\xd6\xf3\xd7\x0b\x00vL~\xc8\x1c\xe8;dG\xe2\x03\x07\x15\xe1\xa8\xd0q\xd0tkk\x95\xff&6O"-\x11C'
        b'\xbdI.\xcb\x01\x05;@\x06\x1c\xea\xb6^\xcd\xb8\xb6 \r$AY\xae\nb\x84..\x85\x03\x83\xea\xc6GJ\xc3-\xc5\xd9u\x86G\xd9\x84r\x04j\xd2a)\nU\x8c\xc9|J\xd0\\\xf0p\r9\x89\xce\r'
        b'W\xfe|e>u=\xe0\x1a\x074\xfd\x02\xd0\x9f\xbd\xf9\xaeCJ\xb3<\x0cf3\t\x11P`*\x11\x0bx\xd1\xf2\xe5\xc1\x11\x89\x86S\xf8E\xdfz5\xbf\x15;@c\x8dN\x87\x94\x9e\x98\xc64\xee\xa7\xe7]\x83'
        b'\xb4\xa7\xf1\xf1\xdd\xebY\x8boX\xccA\xf2\x9e1I\xde\nf\x7f\xab\xc3\xe47P;\xfd\x8f\xb7\x9a\xc5\xfb|\x0ca\x03\x8b\xc6\x0c\xc9\xef\xf2U\xe3"\x88 \xde\x87\xd2\xd8\xa5\x97\xd6 \x0b\xfc\xaf\x1b3d\xc2\x19@'
        b'V\x91FX\x0f\x9d\xc8O\x13\x1b\x81\x08W\xccl\xd2\x90k,\x80*6\xd89\xc2zZ\x8f5\xa4\xcd\xc4\x85\xd4\\\xda\x0e\xff\xbb\x85\x1c\xbe4z!18\xff\x7f2>\x84\xe4N\x93\x95_:(1\xdf/[\x02'
        b'\xdbX\x15\xd9\xff4\xe3\x1d\xcd\xe9\xef\x01^A\xb1Nc!\x06\xe5\x11x,5\x88\xf0\xca\xd3\xd6.\xc88\xa9Q\x02\xe8\xfa\xe8\x10mm\x13\x1cst\xc9&\x8f\x1e?\xe5\xf6&\x01m\xf2\xdaOh9\xb1\xdb\xb1\x02'
        b'!\xab\xbcc\x8e\x9c\xe0U>p~2\xda&\xd7`E\xb3\xd5\x1e4kj\x9e\x0c\x8e\xc5\xe6%\xa4X]l\xff~\x8a\xe9*S\x151l\x10gm\xd4\xc6Ob\x82\x85S\xe1\x8bf\xc4\xe3\xa94:n\xbfeA'
        b'\xe4G\xe4#\xee\n.~\x1b\xf1SwX\xa8\xb8\xf7[\xbc\xb7\xa1sB\xc7\x12\xe1L\xe7aRk\x8b\x82[\xf8\xd9\xcb\xbd\xef(*N\xce\xf3\xdb<\xff\x0e\xb1\x01{\x91\x90\xb9^\xd9VRK\x81if\xf83\xc7'
        b'\x0c\xd6,\xa9\xf0\x1f\xb3\xf8|Y~\xfb\xd1\xd2\xfe9\xf1w\xd4k;\x0b*\x1f}\x8f\t\xec_X\xefU\x1eS?\x1e`\x8e\xf8Z\xc2u.u\xde\xe85_\xd8\xa4\xf8\xfe\xc5\x11\x055\xff\xc5 \xde\xcc\xa1\xe3N'
        b'\xa1`\xba\xc0\xa4\xd4Ix\xe5N\xd2\xa3\xd4\xe5\xae\x9dV\xd5z\x99\xed\x14\x08\xdb&\x9dP\xdaC\xb5\xd3=l\xe9i\xeb\x05\x99\x10\xc7\x18\xb9\xf0\x0c\xf1\x14QF\x84\xd5m\x93\xa7\xb0\xe7Z\x10\xd4\xabZ\x134>\xdb'
        b'\xa0DZ\xbc\xbaFH\xea\\\x9b\xf0;\x909\xba:\xc2U1j\xf8\x0c2\xd1\xee\xd4\x01\xcc\xdf\x0e8Z\xadbP\x14{o\x9f\xef@\'r]\x0bm\xf3\x88"\x9d\x93\xf7\xb2\rY\x9e\xf5\x0c\xb6R\xacU\x98@'
        b'\x93\xf4\x88\x10\xec\x8bQ[\xeaI\xc6\x14J\xa9b\xb7n\x0c\x87\xd9x\x1a\x12\x86\xc9\x12\x85\x0cWj\xb5\xc4\x1f\x04\x99\x99Z\x8du\x80\xfa\x93w\xd3\x01\xd2\xc9&_Q\\y\xb7!#\x80b\x14Q`\x92\xfbr;'
        b'\x92\x1a\xf2\xc7=\x06\x81A\xfc\xff\xfdXXX\xb6;R\x00\x984\xf70\xd64D\xac\xc4N\xdd\xde\xeb@\x83\x15\x8bf\x9b\xe6\xe9i\xf2y\xaf\xdaV\x13J\xa9\xb20\xa4\xf7`\x19mM-M\xde\x0eT\xaa\xc6\xcd'
        b'\xc4\x81,\xd4\xec\xe5\xad\xb6\xfb\x8f\x99\x99X(\xbdi$\xd2\xa8|\xd20\xc7\x8a\xdc/\xef[:^\xed\x88\x80\xe6\x8b\x86:\x9c\xd1\x8dV\x8e\x1e\x91\xe9h\x81\xb7\xa9\xe6\xf9\xc5\xe1\x8f\xfd\xaa\xe8G\xd12Kk\xa7T'
        b"\xe3Wc\x1b\xa6\x9c6\x92\xf6\xfe\xc5\xf0\x85f}K\xbc\xd23\xa5v\xb4\xeb+v\xf2s\xb2\x94\x08\\[:\xa0\xe6\x87\x0e\xbf\xf9\x96\xfd\xb41{\xf4\xe9\x10a\xc2\x04\xfc\\'\xd5\n\x96F\xe7M\xe1\\\xe8\xd2\xa1"
        b'\xd0\xe7+\x15!\xa93\x8b\x99o\xbcpz\xa1\x04\x9e\x9b\xbbq\x96h;\x9c\xa3)\x8a\x95\x8d\x1dj+\xb7\xfboK\x1f\x15\xbdAm\xdd\x13\xc2\x8a\xd1,J\xb0ol\xeaV\xed\x81r\x8f\x00\xf3\xe0D\xbe\xe7\xd5\r'
        b'\xbe\x07\xdc\x9b\x1d\xd15\x07\xce\xc5\x86\xc5K\xab\x01Jk\x9eh3\x1d}\xfd\x8d\xa2\xefVe\xdc\xe2\xf3\x1a\xc3\xae|\xf2\x98~1\xea\xc4\xc2vnZ:\xd1`\xeb\xb0&\xd9>*z\x81i\xa4\x15\x15\x9aD\xee\x1f'
        b'\nP\\\xf6|\t\xd3\xa0\xc3\x13\x008\xf13\xa0`e$\xeevM\x01\xa0@\xce\xe8>$k\xf607o+\xa3J\r\xca\xff\xb2\x89\xbfE\xc0\xd6C\xd6\x96EO\x9b\xc1\xc8eF\xf7gR\xc2m\xe2\xc2\xb0\xcb'
        b'\xef\xf9\xf3\xac\xa4\xd6\xefzS\x02\xef\xdch\x0fvN\xcf\xe5\x18\x8du\xbe\xa3l\xf9\xad \x97\x85~\n!7>L!Q\xc9\x9fs\x1a\x0c%\xfeR\xbe\x0bZ\xe9e#C\x87\xf17\x1a\x05\x10\xea\xc0\xf2R\xf6\xe6'
        b'\xa4\xfcI\xa9\x04\x93\x17D\xd7\x05X\x82\xc8d\xb0\xcb\xab\xd7"7\xc1\x1eQ\xa8\xbe\x00\xd0\xacM\x91pL(\xa9K.\xee;\x0fID\xd5o$\xfaAFu\xc8\x88d\x11v\x96\xbc\xc8\x91\xb9\x02\xb8E0\xf1c'
        b'\xad\xd89\xb5e\x87\xa71P\x04\xae\xbd\x81H\xf3\xc0sS\xceA\xc4s\xf4z\xff\xbb\x7f\x0b\xf8\xecD\xcaf\xb2\xb0\x8d\x83\xa8\x0fC\x0f\xec\xf8\xb0\x12.\xd9(\xd5mmZ\xd5\x1cAe~\xf2\x06\xe8\x90w\xda\xfb'
        b'&\xb8\xd1\xe0\x17\x7f\x92\xe5O\x81\xa2\x14\xfa\x7f\x03\x11\x84\x89G\xbbL[\xff\x04\xcd\xb4\x82A\x82\x15\x15/\x95t5\xe2\xb4/\xa3\xc8n\x85\xd0\xc4p\x02\xc01\xfa\x1242.\xdf;\xd0\xef\xc9\x8d\xaf*q\x1c]'
        b'\x90Cy\x1a\x19a\xa3`\xe4\x07\x89\xe9F\xc3J6\xe2\xa1\xddL\xfd\x8c\xad\xa7\xe2g+W\xf7\x99H\xfd\xab\xe7\x10Q\xa7\x8a;2\x98\x07\x9b"y%\xdd\xd5\xf3\x9a\x81\xd2!j\x00\xf5\x13\xf8\xf7.D\x1f*c'
        b'\x940k\xa9[d\xc53\x8a\x17&\xb0H\x1eg>\xdd\x8f\xc3n_\x08\xe4\xbbs\x10\xaf\x16\xe6\xe8\x94\x8f\x1f\x9c\xa7\xf1\xb0\t>\xd8\x0e\xa6 O\xf0\n\xa7\xe1\x9d~\xee/\xa1\x84a\xd9\xacs9\xc3\xd8%\x7f\x82'
        b'\xa8\xf0A\xe1\xeb\xd8\x96P\xef\xab\xe4\x19-\xa3t(\xde\xaf\xe5\x86\xc4\xb9\xba&\xdb,$AG\x9bI\xe7\x10\xae\xa4\x95\x18\x17*\xf36\xd3\xc1\x05\xb7\xe26\xb3\xe2\x92\xf3\x9c/LY\x8a\xa9\xa8\xf4f\xf2\xae\xe9\x7f'
        b'\x92\xb8O\x97\x95\xcd\xb69X\xd8L\x95\x08\xac\x98o@\xef\xcc\xd1\x03:\xf8\xb0\xd4\x07\xe4\xe2\xb0\xf5 \xa6\x9b\xa8B1\tSi\xc3\x17h(\x047@\xab\xb4|\x91\xb2a\x86;@\x17\x9a\xd2\x96\xa7D\x0b7\xe4'
        b'\xab\xe6\xfaG"i\xc0\xf9H4|\xcb\x01\xebn \xe67yB\xf2a\xf2/*\x05\x17S\xa8\xdf\x8fs\x9c\xf3LqQ\xff\xa5I\xea\xfa\x17\x0fa\xd9\xad\x1f\xb7\xf7\xc5\x9c4\xd9\x8d\x0c\xa8\r<ri1%!'
        b'\xde\x9a\x82gM\xd2I;v8\x03N\xb5"b\xd4\x048*@\xe9\x9e\x97>\x9e\xc3_\r\x98\xfc\x83>\x94\xa0U\xb9\xee"Z\xb5X\x81\x01\xc7\x8f\xd6\xef\xdf\x9d\xc9\xab\x1b\x02\x97\x10\x85GB\xc7\x15\xf1g\x03N'
        b'\x1e\x0es\x88f\x01\t\x92\xbb\x0f\xb6[j/\xa8m\x96\xe0\xea\x9b\xbfj\xaf\xf3\xf3\xc6\x00\xf7kq\x9d\xd8\x84\xd8\x94u\xb8B\xc8\xa4\x9e\xa3q|V\xdf\xc7\xf5vY\x97\xbe\x94+\x8cR!\x9f3\x05K\xb4T\x9e'
        b'_\x10`O\xd0\x9c\xd9\x1e\xdf\xf7\x95\xe9d\xbd\xc4.\xef4.\xf4Mg\xd5>tz\x84\xda~\\K\xbf\x13\x18\xf7\xe87\xf4\xdd\xb9s\xc5\xecq<GQO\x94,\xa2\xca\x9f\xe7\x9e<q\xa1\xd9\xd1\x05\xee\xf1:'
        b'\xb3\xeb.O\x1b\xe3g\x8d\x9b\xdcWq\xe6\x8b\xc2g\xc12ISJ\xfc\x86\xf0\x87\x98\x19\xe7\xeb|Vk\xcf\xe0\x07\xd0[\xd7(Yg\xfe+\xb5\xf1\x85\xc8\x0e\xc2\xf8\xa9(\x83I\x1a\xbf\xf6A\xf1\xa8\xf9!\x9fE'
        b'W\xed$\xcd\xd9\x16\x07K\x81\x81Z\x7f\x10\xda\xb5C\xe7\x99A\xfe\n\xc3\xd9\xe4\x844\x10\x9ak\xddW\x94\xc8&\x19#\xedq\xee\xd7~S\xff\x86\xb7}\xba\xb7\xffEx&tl1As\x07e_\xfa\x99\x83.'
        b'\xe6V\xf5_\x16S(:a"!\x9d\xde{\'9,\x99\xa0\xc4B\xc5\x05\xf1\xd2\xa5\xb1LW+\xdd\x02\xe6\xcdd_\x08\xdf\x10j\x1e\x8f\xbc\xfc\xd96\x0fg\x82\x81=\x04yB\xe1\xcbP0\xe7\xe9?\xa2\xfa7'
        b'\xb9\xc7d\xe4|\xed\xb6&\x1c\x835\xff\x86c\xe1\xe5\xa6\x1dA{N?g>\r\xe5-\xe1\xf3\x17O(K\xc4\xf7\x0c\x9b\xc6\x17\x1c\xec-\xda|W\x93\x1f^Y\x84\x0f\x070%\xad\xf41\xb7v\xb2\x0eQ^A'
        b'{\xe0\t\xfe\xe24u\xb1\xd0\xcc.p\xd7\x82\x13\xa6>\x8b\xeaN\x1b!\x90[\xadv\x86\xe5\xd9\xbf\xd5\x94}\x01t\x18\xd4\xd9\x8d}\xffx\xfe\xaf\xaf\x16R4\xe2\xe10EXg\x8a\xd5\t\xbe\xbb,\xea\x08\x9bM'
        b'\xa7\xe7\x1c^T\xc8sU\xcf\xf6\xe1\xb3\xd6\x17%^1"\x0b2,+jj\x16\xf6\xc0j!4\xb6\xb06\xe2zEEv\x0c\xa1\xd8c\x8d\xbb\xa4\xec\xd0\x1f\xaaNX\x14(\xd3\xa8\xf1\x1b\x97\xcfc\x7f\xf7\xb0\xf1'
        b'\x96U28\xa7\xa4xN\x94\xe0j\xea\xe8\xe78\x82\xeat\xee\x89\x8dH\xd2;\xf2\xba\x84Q\x8a$I\x0c\xeaVh\xb9?\xba\xb0\xd7\xc5\xd8\xbd\xcfQ\x05Q\xa1]\xba\xf9\x9b\xfd\xf3\x84\x83\xf2>\xc9(]\x8cS='
        b"\xe2\xfe\x87\x12 \xe9\xbf\x02\xda\x02\xa5\xd6S\xb0\x9al\xc5C\xf6AL\xab\xf6\xbakL\xb4)\x9f\r\xfe\xb8\xd3\xf2<\x96\xbet\x81\xb6\xd5\xca\x0bL\x19P8\xcb\x7f\xfdj\xd6\xacb1\xfb\xec\x9f'Mv\xc2^\x15"
        b"\x11\xfeR\x85\xf0\xf1L\xc3\xaf\x1a \xd7\xb7\x8c\x8f's\x14\xc6\x8f\xe6\xa8\xd2\xfc\xf2\x84ro\x15\xcb\xbd$R\xfb'\x82\x0f\xe6,\n\xbc\xfc\xed\x07(\x15\x01\x93t\x8c\x99\x91p\xac4\xebo\xed(\xf0\x8a[\x1e\xe9"
        b'\x82\x93v\xf2$\x8dB\xb9\x84)\xe0\xa2k0\xb6\xea-\xd4eWk\xe04-\xc3/\xb3p\xd4(=b\xf1\x00\x1b\xaa\xc4e\xe2\xcb\xd4\x9eo_\xb3\xb1\x83\xa1\xb1\xc1\xe4\xf0\x9b\xa2+O\x93e\xfaI\x0cb\xa3\xad'
        b'\x11\xed}\x17o\xf8\x95\x18vC\\\xb7O\rX1\xf7\x01=\xaf\x8a-\xef\x14\x84\x16\x93,"XjU\x15\x0b\xa0\x7f\xa8\xe6p<\xd9\xd6\xf0\xa1\x16Z\x98|:rC\xae\x86\xee\x9a%\xad\xd5/.\x91%\xff\x94'
        b'r\xa3\xdf\x0fVp\xf3r\x15\xaeD,d\x8e\xe8MI)\xbbK\xff\x13F\xa1\xb5`q$\x7f\xb0\xe8,uA\xba^X\x0f\xfazX\x95a\x1drge\x1ck\xc4\xc6VJ\r9\xf2\x0b\xfe\x81\nS\xce\xd7='
        b'0\xf2\x8b\x80Q\xf5\x0f\xa2y\x9a\xcc\xd4\xab\t\xd3\xa7c\xe6\xaf?\xbd_\xdf^9]\xd8\x95g\xb7\xb4{\x1b\x0e\xdb\xad\xa8#\xd1\xe9!\x80D\xae\xba7\x95c\xb02\xfb4@0+k\xc3\xa7\xc3\xbdS\xd5g\x1d'
        b"\xb3\xdd'\x8d\x1e\x7f\x89\xf4\x0c\x03\xca\x08\x93\xee\x18\xd94\xf3\x1ew\x17\xc2\x80\xcf\x8cd\xd7d\xd9Q\xb8L:\xc5_J\x80\x077\x8d\xab~O\xc6\x93\xecV\xd1\x8a\xe0Jf\xe7 C\x1b]\xb2\xd9\xb5\x11\x1b\x80<"
        b'J\xd1Da\t\xc1\x9c\x1a\xd0\xb3(r\xab\xfd\x1b)\xeciG)\xeaVRK\xe2\xf0"nH\xebD2)\xc4-Cq/\xc2\x94Bd\x0c]\xb5d\xd6\xe0b\xeb\x7f\xec+0\x04!\xdcg6E\x85\xb9D\x1d'
        b'\xf4rc\x06bu\xe2\x16\x07\xa0\x8b\x81\x95A\xd0%\xa1)\xfck\xef\xf9\x0f\xf2\xed\xce\xe2\x7f\xc1\x91}\n\xa8\xc1\x14\xf0R\x1aw\xc4\\\x14\xf4\xa1\xb5u\x0b^\xaf\xf0\xa8O\xb7G\xf8\xc2\xf1\x8b}\x86\xeb\x80\xa0\x9e'
        b'\xf9r\x00{\xd4\x06\x89P<\x11:\x11ZM\xb8Bd\xe6\xda\xf3\x07zc\x94\xd8@\x87\x16\x13<7\xeb\xe28\xbbj\xdaY6\xee\xce\xaf\x83\x97{\xd8\x1ab\xcd\x83#h4\x9b\xe4\\\xf3\x14\x1a\x9b`\x80\xde\xb0'
        b'1\xfa\xde\xffd]\x9b\x90\xc1\x95\x10\x03\xec\xa0\x96\xa4W\x0c\xa5-\x1etle\x08\xd3\x8c^\x9dx\xa0s\xdf\x17\x88\xde\x8c\x0f\xb5Eu\xa0\xdcO\xd7\x00\xc4\x11\x8e\x96\xde\xe8\x0ee\xbe\xc1\xf8\xe7u\xf1\x9f\x19\x0f\xaf'
        b'+\r\xfc\'\xf1\x9e;[\xcay\xcbl\xc1\x85\xc4\x13uZ\x17\xc0\x0e\x97\xb1\xdbP\xf1\xd9\x1f<l/\x93\xc1v\x88\xed\x02`\xc8w~\xbd\x86\x07\x8e\xe5\x91\xf5\x00\xc5"\x10\xd7\x8e\xa2\xa2\x88\xdf\xaa5\x91bri'
        b't\xedF!\x9d\xb4e\xd2\xe8\xfc\xbbcY\x14\xcd\xed\x13\xce\x9d\xc6qY\xd4\xc2Hl\x19|\xc2\xd0\x0f\xf6\x000\xe2\x84\xcc\x96q@\xb0\x0cG\x83U\xf0\x0b2s\xc5\x84\xad\xa3\xa0\x8d\xf6\xbb\x86\xc3\x9bl8\xa91'
        b'\\dK;\x177\x89\xf7D\xf9@I\xf1cv\xea\x99\xe5\x17\x9b\xfce\xb8\xb9F\x9f\x88\xcbHo\x0f\xeb\xfbd\x8f_\xef\xcd\x82\xf1O\xab\xb0?\xcc\xda\xa2\x0en3!)\xd8k![\xf6\xa0\xfb\x9e1\x0f _'
        b'\x8dv\x99sJ<(M\x93\xb7\xf2\x8b\xf9\xe1\xdd#\x07\xa9\x97\xf3\xaf\xe1\xd6\x06\xb4&\xa6\x18\xd4W\x04{\xc51e*\x15e\xbe\xf3\xd9\x08\x8e\xe3\x81\x8b\xe1w\xb4}\xc1\xe2\x93p]Zp-\x03\xf5]y&\xc3'
        b"\xacZ\xe6\xea \x7fj.\xa6\xbd^|\x8cg0\x17%\xbc\x89\xc6\xaaAz\x1c\x94+~\xf6\xaa\xd5\xdb\xf1!'G\xa9`\xc0 9\x96\xee\xda\x85\x04\xef\xe9\x9b\x81\x18\x03J\x1aLy\xf3f\xea\x83\xca\xa5\xf6|{"
        b'\xbe\xa5\xd2 \x1eP\x18U\xdb\xdcu\x06\xfd\x0f\xde\x81\xad\xcf<\xac\x89\xfd\xf2R\xb1\xcb*\xfeB\xa3CL+\xf9\xb1\x18ms\x0c\x0e)\x10~X\xc7yNo\x9c\xb1\xf3V\x00\x92\xf7Iz_\x08\xb0\x11\xa2\x83\xd1'
        b'}\xec+\xd6x>\xf1\xa92gM\xe8\xeb\xa6\xf2(\\wJ\x9fU\x813\x08\x16\x9e\xe36\x8d\x8f\r\xc0y\x05f\x17\x00\xd6\xafG\x86n\x8dH\x1a\x99\xc1"-\x81\xcb\xddTc\x81\xd8\xa1]\r9\xac\n\xfc\x9d'
        b'\xf4\x93\xd2\xfa\xc1 \x15\x89N\xc2;\xee\xbf\xbc\x91\xc4u\xf6\xa2\xa6\xf1\xb8\t\xfbp\x8df\xfb+}\x9f\x86\xb7\xe3\xe3\x14k>\x04\n\xce\x03\xe4=[Aa\x9dm0\xa0\xbd\x07H\xd7\xff\xee+\xd3]\xb0\xf1D!'
        b'\x11\xb0j\xc2M\x89\x86\xe2\x88\xc0\xa6\xbd\x86\xf88\x96\x8e\xeaQ\xe1Mx\xf9\x8c\xb1\xf4!n]\xa0\x81\x1c8\xabW\x92\x00\x033v^\xfa1\xef)Y\xc9\x04w\x8d\xd1`\x1e\xc0\x88\x1c\t<\x90V\xc2\xd9(\xa4'
        b'H\xaa\xa0:\xd1\xd1\xaf\xfc\xb7d\xf4i\xae#\xcf\x9aquYt@<\x02\x19\x06\x9e:-\x04\xed@s\xf5\x10\x15Tct\x1fsi\xbc\xfd<\x99\x00\x88\x94\x93\x87To\xec\xc2\x12\xc0Y\xb2\x94\xc3\xecK%\xce'
        b'\xb0R\xe6\x04\xb2\xefz\xd3\x8d\x90\x99\xe0\x0f\x1c\x16\xe5\x0fX\xa7\xa5\xe0\xcfc\tr\xeeb\xb9"\xac\xec\xb3+\xc8\xb7\xd7\x8e|\xc2\x85\xf9\xfd\x11\xc5\xc2\xcfm\xa5\xb6K\xde\'aJ\x9d\xd6\x1c\x9eMS\x8a\xdc\xf6l'
        b'\xe6^+Z\xdd\xd1\xe3"\xa9xq\x15\xec\xdbmE\xcf\xdf;\x16\xcd\xd5\xa2\x1c\x9f\xa4\xb8\xf2\xd6\xf3\xce\x97\x9a\x0f\xeeU\x0b\x07\xdc\xb1\x1a\x83\xbbI&\xfc\xd2\xcf\x8aq\x14\x97\x06\xad|d\x9b.q\xc9\x8e[p\xa8'
        b'/\x17)\xa9\xa2B\xe9\xba\xbfkw\xd1\x1bs\x16b\xf5\x10\x86\xc1W\x1cB\xfd\xbcg\xa5\xecJ\xdc3\x1b;\xe0|\x02\xf7\x1f\x13F\xee\xad\xcbP\xec\xd9\x12f8\xaa\xe4$\x17\xe7\xdf\xaa\xeaA\xc2\xb8\x15(\x88f'
        b"\x87\xd7\xec\xa0\xa2\x8c\xc96Q7\x1ek\xe2\x91\xc2\x1bct\xbb\xef\xaf\x92$\x02\xfc\x1b\x8f\xd0\x82w\xfc\x16\xee\x04\x86\xbf\xcek\x1e\xb4\x90\x1ez\x0f\x1f('\xb5\xa5\x1f\xaa\xf1\xfc\x9cR5\xa5\xb5ex\\\xfes5"
        b"y7\xb7\x15\x7f\xcd\xe2ql|\x14h%\xce\xa2\x94\x0e\x13\xf7\xd9\xa5\xfaZ\xf9.\rA\x82nu?\xf5\xe6\x8e\x19\xc959\xfd\x01\xcd\xd8\xf1\x99\xee \xb7\xf9\xc6'\xf8nF\xaa\xd2\x04\xbf\xa8\x90]\xc9a\xads"
        b'\xcb\xc2\x95D\x08\x94\x92\x18\xdf\xe4[\xe1-\xc4\xaf\x83+\x1dS\xf7\xf8\xd7\x9a\xf8\xe7\xd4\x18\xab\x87\xe5$\x046\xbf2\x82k\xff\xaeD\x9b\xb7\xf2\x0b\xb1\x88V\x9d\xaa\x8dA\x80W\xfd\xb9\xbc \xc5l\xaa\x7f1\xfb$'
        b'\xf6>\xcd\x07\xf7<\xf5X\xa3V\xb2\xff]I\x08\xfe\xe4WY\xf0\x8e\xd13\xb7o\xdb\xa2H|>\x1fk\x8eL9_\x1c\xcfQ1\xa0\xd4\xc2\x0b\xa2\xcbW\xdbz\x14+\xd0\x9e\xd2\x9c\xf2R\xe7\t\x97\xb5a\xb0\x16'
        b'\xaa*v\x94\xf7\x89\x00\xede\xfc\xe9\xaa\xaf\xa0\xc1"\xc7"\x99\x1c\xbd2\xbd\xf0\xd1\x1e\xb1\xde\x7f\xcc\xbfPl\x02\x9a&9\xb2E\xc7\xfa\xb9P\xed\x9b\xda\x8eQh,g\x92\xf2\xdc\x122PM\x18\xad\x01\xcfy\xa0'
        b'Lj4\n\xca\xc3-pc\xaea\x82+ve\x03\x94\xfa\x83\x1de-\x19\xa3K\n\x81\xcdo\xf6\xf9-\xd1O \xfa\x04\x7f\xc2\xfc\x19c\x8bGR2\x97\x00\xe9\xddW <\x0c\xd4\\e\x91s\xb6\xa0\xb7\x98\xa8'
        b'\xbdV9\xcf\xfe\x1b\x9d\x06\xe9\xf2\xf8A\x83\n=\x06r\x1c@\xb724\xd2,\xcbU\xea\x1a\xd7\xe1<\xe4\xcb\x1b/A(\xec\xc0g\xd2\xd6\xfa\x93\xe6\xccz\xea-\xb2\xf1s;\xaa\xe3iH\xe0\xd1\xaaY\xce\xf1\x14'
        b'\x87I\xe1b$\xc4d\x12Xd\xa55\x82\xb0\x19X\xd5u\xadA\xc0\xdb\xf3\x81e\xec7\x9b\xcb\x15\xad\xf0\x04\xa3\xa3%\xf4\xa9\xe32 \x05\x00\\\xa0\xa7Hk\\\x18\x8a\xbc\x8a\xd9\xd7B\xa2\xb5\xfb\xcc\xf1\x13\x9a\xc0'
        b'(lR\xd3\x84\xf8\xd6 \xb6\x82U\xe260\xd9\xf9\xd6\xfcnhIeKh\x12\x89\xcb*)b}D\xb2\x13\t\x18\xb6;d\x1f\xdb\x1b\xfd\x0eo\xf8\'\x1f\xb7u\xaf\xbf\xf6~\x9d\xc4\xe4\'q\x97N"o\xac'
        b'4\xac>y\xadz\x97\xa18)\xbc?ba\x90P\xe1\x13wq\x16?\x9c\x8bE\x08\x8a\xd2\xe3\xe9\x04\xa2Fo\xed\xe8g\xdab\xd9\x00\t\xa4\xc32\xc9\xe8\xa0w\x8e\xa5\xb4\x95J\x9d\xc0_\xa1;z\x03\xff1\x16'
        b'(\x02\x91m\x94\x8bf\xcc\xc1d\x06_\x10m<\xda\x88\xac\xe2\xfe\xa1.\t\x0c\xeb\x00B\xdf),wZ"\xa8\x1ei\xf3\xd9\xfd\x83\xcc\x93P\x96C\xa1{+"\x81\xc3\xb5\xfdp\xe9^\x9a\x85b\xde\x87#\xb5Z'
        b'\xdd\xc8\xec\x82\x05\x8fR\xc9G\xe2\xea\xe6Mp\xfd\xccgA\xcd\x0c\xa5Ij\xe0M\xfd\xfd\xe8\x88 \xde\xb2\xe1\xdd\x1a6`I\n\x0e\xeb\xfeP\xc5\x96\x9a\x94_y\xf3b\x81\x0ec\x8f\x99cM\x16\x14\xce\x9bG\xf3'
        b'\xf8\xff\xc2L\x9c\xdd\xbc\xee\x9dcW\xe4\xe2\xc2\xda\xa88\xfc\x11\x8d\xa9J\r\x8d\xc6\x13%\x03\xcc\xff\x88\x1c\xf1\x9c\xc3`\xa1\xcb\xb8z\x9c9\xb0]Em\xa8\xc5Rk\x90\x1b\x1114I\x8d\xcbr\x17Q\xdf]\xbc'
        b'EY\xe5m\x05\xa1\xb1\xcf\xf32\xd2F7\x90yS\x8a\xf5bh~x\xf6\x8efkv\x85\xcc\xd4\xac\xe7fmY}\x93<r U\xd0\xec<\xd7\xd8\xe1}\xf8z1\xc5\x8bk\x80\x86&\x99n\x0e\xe9\xe0~\xe1'
        b'\xee\x9c\xdc$Fv1\x1bq\x1bRaIW\xd7`\xb2\x9a\xef\xd2\x05As\xe3\x03\x8b\xb3\xf9\x02\xa7%S\xb2\xe8\x9d\xac8\xe8\x9fx\x1a\xbf\xc3\xd2|\xe1zu\xe3\x1f\xc9O\x99f8\x92\x98\x16c\\\x88\x0c\xb1J'
        b"\x01\xf1\x15m\xf7j\xf0\xe0\xc3;\x0b\x1c\x04\xa0\xf7\xfca'\x859H\xedC\x0f+\x10\x11\xc5\x01x\xa8\xc1\xf3\xb5\xc7H6\x82\x0f\xbc\xc5\xc1q\x83O\xc7p$\x98&\xa8\xc4\x1c{\xdf\xad\xc45\xee\x1f\xdd?,P"
        b'Z\x83x\xdd#\x0c\xef\xc8\xd4X\x05w,vF\xbd\x0b\xb1\\ \x1a\x12^\x8b=\x0c\xf4\x15\x1a\xd6J|\xda\xbf\xc6_v\xd1Y\x0b]\x9a"\xd8\xb2\xcds\xdd\x932J\xc6\x16v\xe7\xa2f\x9ea~\xb1\xd7\x01\xce'
        b'=?(\x01\x9f\xf7UY\x1eo\xb3\xc7G\xd8\x80!\x18\x90\xe7fl[\xcc\x86\xbft\xfdE\r*0Q\x97\xf6\xa5;\xf5/\x11.^K{)p\x88\xd2.\x05E_\x088N{)\xfb\xe0\xc0\xb9\x8el\x0e\\'
        b"\xa6@\xb5\xb7d'0]\t\xb8C\xaaZU\xb3\x13\xf9\xd8+\xbf\\A\xa3\x1c\xe7\xaa9/\xafmt'\x04\xcc\x85\xa7\x94~R\xfd\x08\xf4\x9d|\xc3\xe4\x06T\xd8\xf0O\xfc\xd9\xd4\xc6\xd4\xad*m\x12@\xc5B\xfa"
        b"\xc3+\xd9\x92\x16\xfd\x0f\x1dY\x1a\xdd\x91\x920\xd5\x91\xaf/\xd4\xa9$\x0e\xdc\r''\xab\x14\xfa\xaavp\x9bD`\xcc\r\xad\xce-\xfc\xd7yvr\x0eQj\x1b\xce\x90\n\xdf\xea4\x83\xa0P\x9c\x8e\x93\xd4\x81\xc5"
        b'\x1f\x1b@1\x0em\xbd\x90\x00\x02c\xe1^$\xbb\x8eg\x93.#\x00\x0e\x9f\x1f\xbfv\xab\x87~d\x9d\xb9\x8d&\xc9\x17Ak7a\xa5\xa3(\xc5\xde\x1c\x06\xf6\xa3\x92\xe6\xd5M\x02\xaf\x8fuD\xe0\xcb2\xe2\xe0\x1c'
        b'%\xb4\xff\xf4N\xe7(\xe2\xbc\xb2\xb8\x0e\xcb\x97}\x1e\x9d{\x7f7\xa7\xb9\xa5\xc6\x8d\xb4\xd0\xf0\x80\x9a\xd6\\\x1a\xf9}\x1eO\xc1\x88\xab\xa88\x82\xc7\x1b\x13\xd7S7\xa8Q\xd8z\xac\x17\xa7UiM\xab{\xac\xb9('
        b'M\xb4\xaa\xda\xea<\x16\x04\x13F|V\xa3\x97hVh\xe0o@\xb4\xeb\x9d]\xf9\x97\x95}\x96\xbf\xff\x85;Ot\xa0\xc6\x8a\x1e:\xb0\xaf\x180\xaf\x0f\xb3\n*\x123\xc7L\xb5i\x7f\xb7\x92/J\xebc\x92\xda'
        b'\xcb\x9c\x87\xdc\xe0[&\xc1\xbe\rc\x9awC[\t\xfb\xa0C\xca\x10\x90\x1b\xe6\x86\x1f\x9fx$W\xe38BEg\xccY2B\x92\xac\xd0\xd8\xb44\x9c#1\xfeh\xd2O\x88:\xbc\xd4\x89/K\xc34\xe1\xd6\xc1'
        b'k\xd9\x93y\x03Rq\xf9\x9frd\x13Mu\xe7\'\x8a\xfb\xe6\x85s\xa5\xc8\xcf\xc7%0j\x16\x94\xe7\xcf\x89\x03\x0c\xbb\x04\x12\xe6B\x8f\x00j\xf5i\x92\x8bx\x02\xce\xc9"\xd86\x91:\x0c\xde\xd0\x9bT\xfe\xcf\x08'
        b'd\r\x19Dj\xad\x19!\xe3dF;\xad"\xbe\xb11\xfd\x02\xae\xbe7\xeb\x8cl\xfc*b\xb2\x0c\xd4\x1c\xc2)9\x055\xcd\xe0p\x8f{Y\xb3\xd2\x92\xc6\xecb\x04[!\x9c\xf5\xba\xb9(r\xe7\x1du\x9a\xbd^'
        b'\x83\xb6\xc5\xca\xa2q X\xed\x07\xcf\xbbS\xc3\x1b\xa2\xd4\x08\x12Ey\x00\x8a\xd4\xde\x7f\x1cr,\xff\xde\x8d\x872/H\x12\xac\xb4\xa2\xa3i`\xa0"\xea \x8d\x18\xc8\xba\xb4F;\x1b$\xd2>\xf7\xadr00\x1a'
        b'\xc0\xd9Y\x8c\xe3e}\xf2\n\x8c\n)\xaf\xb7\x04?\xda\xffI\xf0%\xe7(T\xb6\x0f\x85\x93_\xeaZ@\x9d\xe2o\xcf"\xa66L\xf2w\x94s\x1dN\x9a\n$\x9a\xf0\xed\xfcEa\x80"Pl\x074\x9b\x05?'
        b'\x0bK\xc6\xa5{\xdd\xeb\xc4\xa8\x05ao0MY\x1b\xd4n\xdd\x99\xc6f\xf5Z\x06\xfa(W*\xf2(\xe4\xf8rH\xb0\xf5\xd8\xb4\xdb3\x00?{nL\xa3\x07\xea\x86\xaa\xac\xbf\xd6>ce\x91\xac\xd4Y4\x04\xc7'
        b'\x87\xda\x0b]\x1b?:\xb2\xf3\xab\xc7\xb7\xbcv\xe3\xa9\xb5\xc1\xdb\x92\x03K\xb7\xe9Y\x9f\x98\xf2j\xcd\x05R\xc4\x9c\xb9n\xc5\xf46l=\xf3j=\xf9\xc1\xff\xe2\x05CD\xb36d\x1e\xe3/\xe3[|\xb4/0\x8c'
        b'\x88c\x00\x1fU?q\xb0\x05\xd5\xc3\xee!\x9fI\x03\r1\xe5~\x94\xac\xcfR\xb7.\x16\xd9v\x8e\xd8g\xc6\xd0\x1b\x8b$\xab\xfc\x01 =\x8d\xfd_c&~-\xf8\x07\xbb9\x87\xbf\x8d\x1d\xb1\xb2\xab\xaav\x93 '
        b'q\xa0\x98$\x86\xd8w\x8erX)\x80\x90`M\xcbM\x022\x070\xc1\xb5\x12\xf1\xa1\xbf\xd7^\xb9\x1bR\xd1c\x98x\xce>\x0f\xf9\x815u\x91\xe4\xa3\xda\xcc\x0e\xd7\x1d\x9f^?\xb1\x8e\xe1\x1d\xa3\x18\x85\xf4\x80\x03'
        b'-\xb9\xe5\x19\x83\xbb\x1dsFa \xefYw\xc5\x97~\xca3\x87\xaa\\\xcb\xbb^4\x18T\xa7F\xcf\xb7\x90\x01\x94\xba\xfd\xf73\xf5\x83\x03f\xa8\xba\xba\xad\xf2\xbe?\xe4\xf6\n\xdd\x84T\x8b`\xb0\x82&\xb4\xa9%'
        b'\x87\xa8b\xdb\t\xb7\x0b\xa7\x10\xa4X\x18\xfa\x1b{"\xc5\xc9Q\xca\xe4dl\x0e\x08\t#vP\xa7\xc0\xd4B\xa2\x01y\x8f\xbexm\xcdWv\xa6\x7f\x0b\xee\x03\x03\xe6\xb5`-(\xe9\xa4\xe9M\x04.\xcdHs6'
        b'\x85\x12\xe5\xb6m\x00\xfeO\x8f\xe7f\x89M&u\x06\x1b\xf5}d;\xd5l\x9a\xe3\xdfD\xf5\x0e\xda"\xc4\',\xfb\xe4\xf8\xf1\xb8\x06C\x84\xa7\'\x944\xac\x13\xec\x089\xeb\xb1\x12\x16/\x90,\x93usz8#'
        b"o\xd0#\xe2\x92\xd25\xbd`G\xf5\xb4i\xad8\x83D{\x17\xf2X\x95\xf8K\x89\xe5\x82\xaf'\xa4\xc6\xac\xe1\xb3a\xde>\xb7\xbc\xe3\x89\xf0\x02\xff\xc4\xfb\x88\xe8\x0e\xb6\xeciR&\xf4\xc5\x16N\xfce\xc4\xbcX\xcb"
        b'\x00E(\xcf\xb0\x9aI\xe4\xbe\\\x0b^\x11\x0bW&\xf6\xd6]0\xa0\xba\x05?\xdc\xdf\x03G\x9e\xc6\xf9\xb9|\x88\xd4\xcb\xf2s\xc4\xe6[\xa9\xe6\xcd\xde\x05\x03\xa9\x80\x80l\xe8a\xeb\x13\xa5\xaaU\x1e\x82\xd4g\x94\xae'
        b'\xee\x89\x08h7\x89\xa0\x82\xbf\xd0\x87"\x19\xdfZd\xe93\x17\x85\x8c{\xe9B\xda\xd1]\xa3\x12\x1d\xdbj\xe2\x97$t/D\x0b\x82\x16\r\x89J\x05a\xcaz\xc3\xd8\xeenRh\xdf\xad\xf2\xfb\xe0\x0eG\x93\x14\x96'
        b'\xb6m\t\xd6\xe5s\x89\xa7\x009\xb5O\x81=\xb3\x8e\x9b\n\x0e\x94f\xc9\xa6P\x05\x90\xae\x1b\x12S\x04q\x83\x07\xda\xe7\xb1\x9d~7Gl&i\x8a\xbfL+\x83\xb2\xccC\x8cR\xfe\xeb\xafj\xcd}\xb15^h'
        b'(\xe1\xbeF5G\x0fG\xe8\xb6\xa8\ry\x98\x80\xd5]\x9bU\xc9\xd6)q\xfe\x8b3\xcfdql\x17\xa1\xf8\xaa\x7f0\xd9)$\x9f\xb0\xa3\x85\xfe,\x03\x82{zND\x1e\xdc\xd0\xfd\n\x0f\xc3&\n\xa8\x96\x93\xa8'
        b"c{\x1c\x14\xb8'~\xc0\x13M\x98\xd4hv7\xb6\x84\x9c\x89/\xbf\r(\xee\xcdN\xb8Z\x83m%\xb3_\xf9\xd16\x19e])\xe2\x97:\xa6!\x16\x1d&\xfd\xb0\xb0\x19\x15\x0f\x81\xb1\x92\xe1$\xf7\xb7\x0eI\xbe"
        b'69\xed\xdf\x93\xdb\x00\x1a\xe7z([\xd8\xa9\xce~d8\xee\x82\x9f6\xebb\xe9\xec\x92\xdca\xdaq\xa7\xf1[1#\xe8\xa9\x11\x0c\x93!\\S\x93\xc6\xdd\xfc\x19\x0b\x95M\xaa(\xf5r\xbd\xf0uY\xf3\xc7\xd0_'
        b'\x90\x03\xeb\\\xf70O\x9eJ+\x8f\xacC\xa0\\\xed\na\x8cg\x1d\xc8\x0chT\xa6\xc6\x92\xd8<?|\xcf\x07\xa8\xe7;\xf6\x19M\x05_\t\x83Ob\xf5\xb6W\xf6%\xbb\xfc\xa2\x90\x15\xa5\x0er\x04\r\xe8we'
        b'l\x1ex^5l1\xbbx%D[M&\xa3.(\x9b:^\xc7\x881\x97s\x16C\xb5\xa0\xc0\xd3\xaa\xcf\tb9;\x13\xd7\xe8\xbe)\xc8\x11\xd2\xa0D\x90\xb2\xfd\xe9\xb6\x06\xd1\xee0gl)H\x8e\x10#A'
        b'\xeb}3K\xf0\r\x10<\xae\xa4\xc7\x85\xb0Ge\r\x99\x94\xfe\t\x1a,\x06\x90\xa4^\x973C\x98\xe0\xd5\x8ed\x89(bzrKJ\xecQH=\xa2\xbdg\x1d\xb7~\x95\xe5@\x80\x8d\x83\x81.\x1cfQ\x81\xca'
        b'!<\xa3T\xd9\xa2:Ny|\xb6\x1am\x83q]\xbcM\xbc\xf2\x99\n\xf7\x95\x83wb\x16\xce\xdeb\x99D\x90\xfcgRQ\xc8\x8d\xf7X\xd5\xeb$YA\xf5\xef9\x16\x05Md\x8f\x94\x03\x9b\x92S\xdbM\x91j'
        b'\xdf\xc2\x87\x1a\x82b%\xac9{\xd8/\xf2X\xbe\x11\xdc,\xb8\xa78\xef x\x00\xd1d\xfb\xa5S\xed\xe0Ky\xe1\xc1bt\xd0\xad38\x84\xef\x8a$Tb\xe4\x94?\xe5\xc9\x88\xbcl\xb5\\)\xc4\x95W\xd4U'
        b'Y\xd2\x1b\x84\x0cC\x98#\xb3\xc0UJs\x9b\xa7\x84\x01\xb5K\xffI\xfd\xf7\x80\xbfd\x1d\x0f\xf2\x00W[\xb2\x866\xb7\te\x94\x90\xcc\x0c\x81\x8f\r\x93v\x8a\x8b3\xd2JF!\xab!\xdb\x868\x1a\xaa\xa0\x1d\xea'
        b'\xf8\x7fo\x96\xa3G\x80W\x82\xf0wfW+\xb0:i\xdd\xd3R%\xd2;\xa9\xd8\x8e\x01\x87\x11 \xe74\x02\x19\x80\x03R\x1aW\xfc\x02\xa6nr\x8b\x1cQ\x0f=\xc1j\xea\x11\x89^\xcbUb\x02\rB9Bf'
        b'\x1e\x9c\n\x1b\xff\x15\x0bFzA|\xf2\xec\x87\xab\t\xf94^\xd6~8\xb6Y\x99\xac\x8a\xfec,X\x82M\xfc|"G\xa2\x8e\x18wX; \xe4\xa8\xf3n\xa0?\x06\xe7\x0b\xf8\xca\x11\x90\x0eue\xfan\xd2\xce'
        b'\x90=MSu\xfba\xe7*\xb0\x83\x9c\xcc>\xffy\x98\xb0{\x19\xf9\xe5\x05\x9a\x05\x8aa\xec\xc64 \xc447P\x91\x13U\x85\x9c\xad\xeeh\xfc\x163\x89Yw\xb31a;\x02O\xb6\xf8\xd4J\xd1\xf0\xa4\xada'
        b'\xbf\xe1\xe9\x9e<\xaa\xac\x82+\x0b\xa6\xa41\r\xf3A\xe0\xdc\xff\x84\x1fy\xd0\xf6\xef\x0e\xfe\xa3\x87\xc3c]\x10l\x06A\xf0\xf5\xdc\xbe\x9bc\x84\x077n?\x82$\xbb\xaeM\xbf{\xcd\xdd\x11\x9d\xac|\xf5T,\x93'
        b'\xee\xd6\x0f\x98\xcc]p)\x9e)wp`\xdb\xf1\x0eD\xc0\x8d\xb3\x92|j\xbeL*\xa5\xeb\x1c\xd48\xc4*\x1cK\xda(=\xd4C.\xa1\xeb\xbb\x8b\xc6s\x00\x1f\x0c\xec\xf5};@o\xeb\x87\x9c[m8\xdb\xaf'
        b'\x8eY\xc7~\x9f^8f\xcd\xfc\x9f\xdf\x03\x0b\x17\x9d\x85V\xe7\xac\xf3^\xa7n0\x0f;B\xadtE\xe0\xfb\xf9ce\x06\xcf\xe5K(\x8c\xda\x91z!dg\x94\xd3(\x9dK\xe1\x9a)]^\xce\x08&f\xac\xa8'
        b'}T\x81\x85\xa1"\x1bjg\xf9\x92\x9d\xbe\xc0s\x88\r[\xed\xac\x80\xf5e\xcd\xf3\x15\xac\xa1\x86\xa0B\xb1\x92n\xf5\xa5\x13\x90\xbe4Z\x81`:V8\xd1\xadHO\x92+H;l\xb3\xcb_\xcb\xd9\xe7o\x89F'
        b'\xaa\xcdg-\x7f\x1e\xac\x97\xc0\xf1\xb8\x16E`7T\xb5,\xd8\x01\xec\x00\xf4\x88\x87p\x9c\xff\xb2u\xe0\xd4\x7fC\x0c\x86[\x1dN)\x07V\xe0\x1a\xdd\xfb5\x12\xeeF\x1a\xf9\xf8MO\x08S\xdfz\x9e\xc7\xe1a\xab'
        b"\xd8k6\xf9--\x0b\\,\xbc\x17L\x06\xa7d\xea<0z\xdc\xaa\xf9\xa7\xb9\x86MB\xd7\xc6\xdc\xad\x15\xc0\xcb'k\xa29\xde|\xc5v\x82r<k\x9e\xe7\xa3\xd7j&y\xed\xea\x97\xaa \xf4\xbb\xe3j\x1eL"
        b'\xac<\xd0\x9c.<$FK\x1eb\x92\xf2\xa2\x81\x13X\xf5lM9_\xa2\xfe\xed7c2\xd5\x80\x92?\xf0\x83|\x17\xba\xf1\x01\xc4\xc4No\xdb\xe2\xf7\x17\x872N\xf2\x80\x93\xcc7n\xf1\x96n\x8c\n"\xb3\x9f'
        b'\xc1\x17\xe9/\x08\xb7\x1c\x8e|\xf3\x98\xd2_L\xe2\x93\xf5a\xdfL\x8a &\x03\xf3#\x03\x94\xdc\xbfs\xd9i\x19\x0b\xfcV\xaf\xfdC\xa85%\xfd\xaaE8\x89\x80\xcf\x0eT\xf7\x95\xc9|\x85"!\x92f\xa1)\x81'
        b'i\x97nk\x15\xcf\xd5B\xa8\x99\x00\x17EWS_\xf9\x8e\xfcLt\x12\x94/J\x10[\xa6\xbai\xbc\xef\x91\xdbjY\xbe\xa7X\xee\xf1l\xfc\x05\xca\xc5\xfa\x14\t\x12\xa5^\x7f\x07T\xdf\xb0\xac\x13v\x00\x90j\xef'
        b'v\xa8\x13\x1a\x93R\xf0\x99\xbaA\x9d\x14y\xdf\x11\xd0}\xcc\x1d\x0f\x10\xe4\x10\x9b\x056kU\xf8\xaa\x8d2h^\x0cpO\xb2\xe6\xd3\x01*\x8fA\xc5\x99L\x1c\xa7\x12\x92\x10H\x9a\x98\x06\xfe\x11)\x02|YG\xd4'
        b'S\x19\xb4\xee\xb3b1\r\xcbN8\xf4\xf4\xec\xc3\x16S\xa2O\xc6\x86\xa5\x86\xe4&\xe5^wi\xd6\x8b\xa1\x8ap@\xd5\xa0\xfcB\x93$Y\\\xac\x1a\xa2WJg\x1c\xe1.\x0e\xdc\xd8\xbew\x8a\xe8Z\xda\xb4-\xda'
        b'\xf5\x1c\x1f\x8cXa\x87\x98\x99\xdf\xa1\x0f\xc7\xb9\xa5P\xe6#\nE\x87\xb3t\xef\xa8C!\xf9s}\x07\x96/J\x17\x06/\xa7\xa3\xc0:\xbe\xd0\x01\xd6\xaak\x8e\x8f\x1e\x0e\xf3U\x95\xd4X\xb6\xe8-\xe2\xaaD\x19#'
        b'\x9bOf\xe7U\xef\xed\xd7\xd5)0\x9fQ\xd5K\xdd}\x0e{K\xe8\xf2,\x94\xf6P7\xcf$\xc8ms\x96\x85\xd5\x85\xd1Y\xf1\x06\x05\x87\xa1\xbe\x99{=[\xf8\xe5y,\x92`\xbf\xbc\xec\xc7\x9c\xc2\x8b\xea^\xd7'
        b"KNB\x8f\xc5\x08\x9c\xf9Z\x1dt+\\9\n\xdf\x80gj\xdb9\xbb\x0c\x92\x88$\xe9T\x86E\xeb5\x96e\xf1fJ*\x17\x15<\xe1\xe1-\xe2\x0b\x9e\xc6\x16Q\xc2\xf0\xb2E\x91;>\xa8\xab\xa4\x02'\xb5\xbf"
        b'\x18\x9d\xdfI{\r\x94"\x04\x94\xaea]\x93U\xd96\xa0\x94\x86\x8f\x10r\x12\xec\'\xe4\xb2\x93\x9a\x8a\x08\xcd\xfb\xd8\x9fi\xb52\x86iG\xb1\xeb\x83+:\xfee\xcc\xed:\x84Wh\xc8\xb0\xfe\xf1\x8d,I\xf5S'
        b'\x08\x9c\x8f\x9c\xf6\xe5v\xb4\x08\x9fd\xa3`\x8fg\x03i1\x1aU;*\xaf\xbbo39_\x19\xaf\xdd\xeb\x00\xe3\xd4\xda}\xd3y\n\xbe\xf0Z\x90\xe3\x86\xa7\x91\x92\x9e\xf2\x15\xd7<\xb0D9\x9b\xc1\x1cp{W\xc8'
        b'$\xa1j\x1dJ"\xdcH\xdcO\x11QM\xb5\xc4\xbd\xd7\x92i\x11\xed\x0f\xec\xcaZ\x1c\xf4\xa2\xb7\xe9\x8c\xc3\xf4\x8f\xe4\xeb\x96U\xe3\xefAh\xc2.@\xa1\x05t\xe0\xac\xb04\x81\xbe<\xd7\x08\x98\xb9\x90\xf3\x8aO\x98'
        b'\x18\xba^\xc9S\xa9\xef\x9a-,\r\xfd\xafO8\xb9G\xa8\x03X)\xa4S\xf7}\xeb\xf9[\xfc\xf8X\xc6Z\xf69\x1d\xc4&\x9b\x8fbo\xe7\xc5r\xc7\xc6\xb3^\x7f\x91TZ\xf0\x92y\x8d\xa4\xa1\x9e\xe4qe\xe7'
        b'\xa3\x8a\x12\xce\xd9@\x0b\xc4\x1e\x01\x03\xd8\tA\xb9X\xe5\xd9\xfcS\x91<\xa6\x08\x04T\xd0\x8b\xc6\xf2FCj\x96\xff\xf5\x06\x1f\x9b\x8a\xd9]\xea\x9dj\xb2\xd7tp?\xa7s\xfe_(\xe9[5_\x15\x7f(Wd'
        b'\xe9`\xcf\xcfMLW\\\x00\xberY?\xe1\xe9u\xd3\x8f=Z\xd9\xd8\xfc\x94\xe8\xf4\xab{\n#\xea\xbc\xde\x17\xed?]en\xd2\\)\xb5\x00\x85\xf8\xda\n\x03\xd3*9\x12l5\xcc\xdf\xa2\x13\xd5\x18\xc1sm'
        b'r\x18\xbaR\xe7\x9b\xf19\x19\xdb\x98u\xb81s\xe8z\xec\xad\xaa\x81vB$\xe7x\x8dAp{\xf3Qm\xb1\xc9,[\x98~Sj$[\x17\x8f\xde\r\x972\xd9\x18\xf4\x0f\x95\x140?Y4}\xc2\xf9LP'
        b']$q\x8e\xb8\x82\x83|\x1b@\x0f\xcb1}\x1ah\xe2E\xa9\xceb\xd3!X\xdb\xe5ITr\xd6.\xcdn\x90\xbe=OZw\x17\xcd\xceZw\x91g`w{\xeb\xac\xd2+\xe6\xff\x12l\xa7\x11\x08\x90\xac\x04\x8c'
        b'E\xd9M\xb9\t\xe75\x04\xe1\x98\xbazV\xbb,?\x88w i3\x1c5Y|\xc5P\x9d?B\xa2rV\xf8\xf2\xc4\xcd\xdewagvF\xd0\xe6\x99\xe6\xb4\x90\xa4\xed\x854\xe4\xd0|\xd4\xcc\x0f\x86\xcdc\x11\xdb'
        b'*\xad\x1a\x1b\xb7\x9d1\x96\xbb\xcc\r\xbe\xf0k\xc7\xa3\xe5\xb5}"*+\xf1\xbf1-`\rg\xcdU\r1\xf0\x18#{w\x94\xd5N\x0f\x8f\xf1fA\xb065\xc1\xc4x}\xcb\xe9\x19\xc9!\xf3i\xec\xdb\x8a\xcc'
        b'T\xbe7\xf6L:.D\xa0B%]\x0f;\xa5\xf9,T:\x1b\xdc\xd4)z\xba|\xb0\xef\xb5\x96\x03\x81\xcf3G!O\xb2(\xecI\x80\xe5\xd3\x07I\xf5\xd6\\\xb67\x18\x91\x9cJHc\x00"*\x05\xfd\xed\xd1'
        b'(\xefCPl\xd0\xb8\xbc\xc4\\5\x87\xdc\x9c\xbb\xa3@Ef\x98P\xb8\xe0M\xc5\x05\xe1\x8f\xd5S\xfa\xe3{a\x1fm\x0bkB\xb1\xbd\xa8\x8b\xf6u\xe6q\n \xcf+\xad\xe5?|\xb6JX\xbfU0\xfd\xc2\xa9'
        b'\xea\xe8\xb9h\x06\xb3S\x1aX\xc1W\xb0\xffp\x9b\xc1\xe3\x91@W\xb2!\xbd\xa3\xf8\xa9<\xe3\xe4\xf9y\x04\x1b\x03,\xfci\x11\x1ftCu\xac\xc5\x9c\x8fW-0\xdc\x8aB\x1dS?\x89\x15\xed\xb6R\xd9\xa8\xbe{'
        b'\xcc\x03{\x8d\x92\x9b\xfa)tP)\xd7\xc6{p\x16y\xf3\xe91\xbc\x84\x02\x04YYdcfEI\x97U\x1f\xde\xde7\xed\x7f\x9a\xce\x11\x92\x13\x84\x127U]\xc5`\xe8\xe9\xa1S\xf8\xb2\xa4\x12vwE\xa8F'
        b"P\x15Y\xa6\xd2\xe3U\xe1$\xb9\x9dz\x8d\x83G\xf8]\xbcq\xfb\x91\xeb'\\eA\x14P\xd7\x1c\x83\xb6Y\xf4\x06\xfa\xa1C=\x7f%N\xdf\xfeyZr\xc5\xaf\xe3\xae\x9e\x8f\xa6\xed\xfb!\xf5\x87\x07t\xd2~\x99"
        b'\x99F\xa68\xc9F\xe8\xde\x008\xd6Z\xf6\\2\xe3\xc1\x87\xe1];\\/\x8c\xc4\xa6e5\xb2\xed\x8f8\xc8\xff\xf3\x90\xa2\xe5:Qeal\xbf%\xfdYzhz8(\xde\xa5\x12M\xa8/0\x86:!\xfbI'
        b"\x03\x08\xa6kn\xec,\x0c\x1d\x91\xd4(\x15\xc9\xb3\tj_\xa1S\xd1{\xcf3\xb5\x92;'(W\xed\xc1\x85\xbc\xf7\xf9{E\x9bS\xeddMg\xe2\x19\xd3\x9c\x9cU]\xd9\xaa\xe4\xc31\xe5\xae8\xa6\\\x91\x1e\xa8"
        b'\x8b\xc6\xec\xa8Wm\x9d\x9b\xb0\x1c\x8c0\xe6\xd2;\xbcgr\x97T\xba"\x0bF\xf0\\\x06\xfd\xec5\xdc\x08\x98lQGa\xb0A\xc7\x81d\x01\xe6\n\xe2.\x7fn\xf5c\xf5\x94\xf4\xfa\x95B\xe8\x80,3\x0c\xfc\xec'
        b'\xaa\xb4Vu\x92K\x15\xb6y\xb0\xa5\xb4\xbcs+\x9d\xce\xcc\x0e\xffZ\x7f3Xj\x85\x93\xc8\xde\xdf\xca\xc2\x1d\xe0\x95b\xa8\xccc\xbfh|\xa2"\x90\x1c\xcf\x91\xe5Nug\xab8\xfdv\xd0\xfb\x855\x0c\x87Qu'
        b'\x80\xe0\xbc\x0eE\xc0>\xa5#c\xcaf\x88\r\xd8\x99\xe6q\xe7b\xd6\x08b*\xbae\xb0\xfd\x93\xaf\x8fE\x9a\xb1<\x7f\xd3\x8a\x1d\x9c\x05\x05k\x9a\xe5\xb0\xf3\x0eF\xa8\xa6\xa5\xf4\xd1,o\xe8\xa8\x1e\xd1\x91\xf9\x15\x01'
        b'o\x9f\xfa\xddi\x02\x9d\xde\x07\xe9\xfdm\x94t\x97\xca@\xb3x\xca\x87\x05\n\xc9\x1e\x12i\xbf\xc0q\xe9\xd1I\xfc\x80\xea\x85(\xd2\xe7\x90\xa6\xdd\xdeL\xb1\xa8\xa9/j\xe0\x11\xae\xb3\xaa\xfc\xdcJ\x99\xc8\xfd\xeb62'
        b"\xbd\xdb\xa2<\xdc\x87\xf7\xf1\xbfS\x80\xe0\xf3\xe7\xbeQ\x9b\xbe5\x17\x04\xe8\xe7O%\xbb\x1e\xfa\xaf-\x07z\x97\x93\x89p\x1f\xb8\x0cT\x92\xd6~\x0f\xcc'X\xdf\x9a\x81\xc71\xa6\xa9+\xb4d\xd6\xb6@\xc0?\xc1\xca"
        b'\xce\x89\x86\x07r(Vk\x96\xb2\x0f\x96\xc0\xf1\xbe\xdc\x16\x82\xc4T\x91\xca`{<\xed\xbef:Z9=\x00\x99\xbd\x86\x12^O\xe71\x9d\x8e\xe5\xc7\xaevO\x90\x9b\x97\t\xfbuX6\xc2K|b\xd91K\x04'
        b'\x966Q\xd4T\xd6\nA\x81\n\xee&\xad\x94\x96\x15\x98[\xcc\x87\xa8\xaa\xa2\xd8\xbf\x0ct\xb7Q\xc0h\xfb\xad\xa9\xf9\rU\x1cZik\xde\x121j\xac"\xc1\xac\xeb\xfb:#W\x08y\x18\xbe\xcf\xcai\xfe\x98C'
        b'\xa9oW g\x16\x9d\xc2\x920\x94\xa7A\x1dS{\x817n\xca\r_\x13\xe9#o\x07\x9d`P3\xe2\xc0\x80\xc1d\xae\xa6Xd\xf8\xa4\xad~\xf2\xc6\xd7v\xe8J\x93\xef\x8e\xa1\x12k\x8d\x9e\x18\xb1\xdc\x9a\xf0\xad'
        b'\xe64\x88\xa7\xc6{Y\x00Nbi\xce\x88\x04J\xfb-a\x8a\x136\x94e;\x02\x88\xd19WV\x15\xc0\xd2\xf60\x1a\xafZ\xbciA\xf3\x0bG\xef\xa7\xedm\x01\x89\xb3\x949\xfa0\x9d\x0eh\x96\x1e\x03\xb6Dl'
        b'\x01\xa5\xad\xaa\xd2\xa0\xfeb\xe8K\xc7l\xfb\xb2~0\xc7\xa2=\x8f\xc0\x0e\x98\x1bSy\x94o`\xb9\xad\xf2r1\xe7\x04w\xa0\xaf\\!\xf96z.>`\xe8\x10+\x06D5\xa2N\xc5.\x11<e\xde\x1a\x8a\xf4'
        b'\x8c\xa0\x8fW\xa0:\x08@D=OA\x08R\x1e\xd1@)\x96\x12k[\xff\x1c\x10`\x88\xe2Pm\xd0\t\x84\x86\xc9\xde.|\xef\x1d\xbf\xecj`\xa6R{\xa8X\xfa\xd0\x10\xcd\xfa&o\x0f\xfaN\xb3w^\xd1\xd6'
        b'\x90\xa0Q\x0f\x89\xc1\xad\xd3\x14v\xf1~:L^%m\\Z\xa5:\xde\x13\xa3\xe6-G\x9f\xcbM\x8b\xae,\xc8W5j\xefwp0a\x9db\x7f\x9f\xa8\xa9m\x1fh\xfa\xf9\xf9\xbb\xb5\x8cj\x18\xc25\x11\x1d\xff'
        b'\x18O\x91R\xf9D\x0b]\x1a\xc6\xa5\x12\xbb\xb1w\xb6\xe9\x1eRr\xeem\xca\xc4\xf8\x85\x17\x8a+\xee\xea\xe2\xaf\x88%\x1c\xd6\x92\xcc\xa3\xd2\\\x02t\x0e\xf2\x15\xd4D\xe8\xf2\xbf\x8a\xac\xa2\\\xa6\x11?*r$J\x8c'
        b'\x03\x8bN\x89R\xe7":\x8f~\xa1XY3\x94\xac\x19\x08\xa3\xb9\xda\x94\xe2;\x82\xa83\xc2tx\xfaY\xa3\x07\x039l\x7f\x80\x08\x12\x10\xb5Gx\xc2h\xc5\xa7\xbfV\xc1\x13\xcb=>?\x85X\xdc\xfb\xa8&w'
        b'\x1e\x1e\x03\xa2\xb5\xb6!^\x04\xfa\x81I>q\xe2\xd5\xa8\xe1\x10\xc3s\xf4\xc3u6\x86\x07\x13\x05>`\xd7\r\xb0U\x04<;\x1c\x14\t\xea\xfd\xff2y\x10F\xf5\x91\xdf\xbb\xe0\xf1\x0eK\xa4\xdc)\xa4\xcd\x99\xec\x86'
        b'\x13(p:\x91\xd4lq\xd9qk\xf5;\xfa1W\xf1\x82fo\xd3\x8av\xb8\x95I\xe6]\x82\x1b\x07\xd1\xb2\xa2\xcay\x80wy\xa5k\xf9\xe6\xeee6\x0c%<\xd2\x87\x85\x04\xd1KO;\xc0~\xb4>\xa4\x0e\x01'
        b'\xc1\xc3\xff|\xfaci\xd2\x97\xd5\x0c\xc1B\xffY\x12\x16\xd0tq\x03\xedO\x9e\xfe\xcek\x0f\xefkE\x82+2\x10*S\x90l\xbb\xd1\xe9\x8d{\x1a\x96\xab\x83\xbb`UJ=\xccN:\xf6\x83\xf3\xb8n\xc9Q\x01'
        b'\xea?\xce\x85\x19\xa6\xdfs\xbcti\xb6n-u\x05\xb8\xe6p\xb06~\xed!J\xbb\x17\xd2rQ\xd9\xcb3\xf0p\t\xe4\xee\xbcc\xa2A\x1b\xd1\xa0\xed2\xf0{\xa8}\x18-\xba52\xb7C\xc2\xa9\x96<\x15#'
        b'\x7f\xcc15\xc8\xc3\xda2\x98!\xc9v\xd2\x8d\x0e d!\xab\x11\x02yJ\xe6\xa2\xdby@\xc6\x16\t\xd0\x8f\xb6\x89G\x8d\\J[\x1aZ\xfd\x81\xf5\x03\x12\xbf\xad\x90\x1d\xf7\xf9\x86\xcea\x9b\xb8\x13\x15\xc4\xf5nf'
        b'\x05H\xd5_\x1c\xfd7\xeb\xaf\xbe\xf2\xf5hc\xff\xfcj\xdc\x94\xb5;\xff\xcdk\x00\x19\xf7\x93\x1eW\xb8\x8f\xb5\xc0\x86\xc3\xe3\xc4\tD\x01{M\xf6C\xc3e\x0e<_\xff\x96ha\x150\xba\xf2c\xbe-\xf7E\xf6'
        b'k\xe1\x81U\xd1\x9b-\x19o\xb0>\xcc\x01m\xc4\xd5\xfa\xf4\xf6\x08\xc2\xe3g\xc5\xa3\xcb\xe7\xc3EF\xcd\x18\x1dgX\x07+h\xe7a\xe4=6\x91\x1a\xe2<K\x18\xe6-&\xd8\xcc\xfc\x8f\xcb\x12)\xb4\xb9\x0e{\xbc'
        b'\x9b\xc3y\xb4\xa7\xa9\xa8l5OL\xab\x0c=\x84\xbaw\x0c\xdf\x97\x89\x07\x7f}\xc2\x1b\xee\x8bH\xba\xb8\x12\xb1\x14\x90\x0c\x04\x06H\xc8s\x8bD\x9f\x08y\x9e[.\xb9\xc9\xffI\x8d\x96\xe3\xda\x90\\\x9dF\x9dgC'
        b"\x914.\xa1\x1a\x0e_\xb7r\x92\x0f\xa8\xb7\x82\x92\xe5C\xda\xf6\xfb\x0ff\xac\xaa\xa5Byw\xb9\xe6\xd2\\eB\xae\xd9\xb06\xe7\xaa'\x1c\x87\x96\xc7\x8c\xd6 \x17l\x92\x99\x83\\\x8c\x94\xe0x\xce'\xfc\xf0\nP"
        b'\xd7\xac\x94\xbcv\x98\x83C\x1c\xf2\x1aEu\x82cp\xaf"\xcf\xf1\xe1:\x0cm"\xc6\\\x17\xf3%Y\xd8v#~\xb8wQ\x05\xd3\xd9v\x80LW\xe23ZB\x05d\t\xf6\xa0\xb6\xff\xce\x9d\xbc\xad\xee\xd7\xa7\xa0'
        b'\x1c\xdc\x06/\x97_o{\xef\xfdlB_\x80N\x1d\x11\xd5\xed\xff\xfd\xc1|\xcf\xef\x1aw<\x07\xc9\xfc4\xf0\x99\x1a\xb2=\xdbMJi\x9e\x83\xe8\xf1\xccS\xaa\xff/\x95\xb4\xa2\xaf\x98\xac\xa7e\xdb\xba[\x9a\xc06'
        b'\x9fD$\xf0\xad\xad#-\xfc3\xa7\x15\xf2\xe8\xfa\xafX\xcc\x8f\xb7H\x1eYQ+\xc1\xdfF\xd4-\xc1{\x9b\x9d\xcf\x89v\x90z!S\xea\x81\xad\xaakR\xde\x1d\x98\xc2]\x8c\xd8\x9fv\xd5\xeb\x1e\xab=\xa1\x93\xa3'
        b'\xcc\xec\x99\xe5\xea\x91\x1e\xe7\xbe,\xfe\xeb\x7f\xbc\x01lb\xbaQ\xb6Xh\xec|\xeb\xa2\xb6\x8a\xa1\x9c\xdc\x88\xe7%Y\x8b\x8c|e\x90eq\xdb\xc7\xf8\xfa_[\x80\n\xacW\xb7\x91\x0e\xbf\xb7\xa7\xa7\xde\x98o\xab\xea'
        b"&\x96\xdd\xe7\xa42>\xba\x0c\xc9\xa7\xb8K\xf64\x88Yit\xa0c\xd6\xe0\x04\xd6'$:\x04\xd3g\x04\xe1\xe1\x8d\x9fX=\xbc(t?\x1c\xcd\x99*\xab\xf2\x9co\xa84\xbdJ\xe0\x19\x0fJ\xa8|\x02\xda\xba?"
        b'X\xba\x1br\xa3T\x88\x91]\x13\xb1 \xda\xc6\x07\x04\xcf\x8e\xe2\xed\x18E~s\x16/6\x05\xe9S\x8c]\xe3\x1b\x1c-\xfe\xb9\\`\xbfD\xb9\xb7\x19\xd2\x05>\x18N\xa6\xc2\x04\x8c\xa2/\x0c:\xa2A*\x01\xd7\x0b'
        b'evE\x1c\xde\xfe\x9a\xe2P\x90\xb0\xc0!\xef\x1b\x8a&\x9b\xe5\x9d\xdc0\x88\xc8B/\x81\x8c^[\xea\xff\x0cRf\x0e1!\xb0\xaa\x0f\x10\xcf\x17\xe0Jr\xa1\xaf\x8a!e\xd6\x03\xc1\x1a\x1a"\x0e_u\xd8\x154'
        b'l\x9b1\x8b\xa5\x1e\t\x90\x99\xd2W\xd3\xd8M\xf6\x11#\x04\xbe\xd9\xc4\xae\x1c\xe9/\xfb\xdb\x1a\x0cc\xdd\x18\xab\x9e\xeb\x8c\xfb\xf7\xda\xc2\x0f\xbb\xac24\xf3\xb8\xb5\x19\x05q\x9b\x08\x95\xc9\x85\xe4\x88ac\xeb\xb2\x0f0'
        b"_q\x81\xd0\x0f~u\xe5\xd2F('\x89^\xad\xab\x17\x1a\xde#T\xf5\xc1\xba*m\x82\xa3\xed\xa5\xf9\x9aJ\x06\xb8.9vl\x06t8\xa0\xa2>\xb1\xf6:U\x0b6\xfd>\xe4z\xe1\xc2\xac\x17J_\xad\xadO"
        b'\xca*\xfd%.\x0bx@\xb1\x1c?\x93x\xb0\x86\x15\xb5\x1b\x80\xf27r\x0f9\xc9\xfe\x17(<\xa8\xb7\x0c\xad\xa8\x8e\x8d\x0f\x16\xe8\xce\xb0\xe4>\x8aZ\x9d\x183\xb0\n\xa7"\nD>\x0cY\x1d\xcfQir\xef\x16'
        b'\x00>\xe6\xb5\xb3\x81\x99\xd3\x9c`?W\xbc\xfe\xc2\x05\xfdA\xf4;RW\xa2`i\xcclh\xc8Lm\x90\xaf%b\xd1\nS\xeb\xf6\xec\xda\xb9\x91\xa5\xc0\xc7\xd8M \x86.\xda>l\xb3&\xb8\xc5\xda6\x1b\xff~'
        b'K/\xe4\xc6\xa8\x16Y \x88\xf0\xa8\xado\x80(\xe5#c\nZ\x86\xa9\xb9\x81=\x96\xbe<\xe6\xbd\x1a\rj\xc6\xadC\x0f\x91\x06\x85@J\xb3\x1b\x10;P\x98\xe2\xcc\xdfM`\x13\x16\xd07\xb5U\xa8\xdaA\n;'
        b'\x9e:Ua\x82\x9eV\xf2\xf7nCA\\\x969\xd4 \x9d\x92*\x06\x04\xf7\x05\x8f\x0e\xe6\x0fC\x00eg\x06\xf8|\xaelA\xd0\x01\x00R6\x89us}VW\x9f\r2\xadCM\x1d\x08u\xad\xbb~=\xdb\x92'
        b'IZ\x82\xf3\xc6bHM\xc1\xd6\x13\xc1[f\xe0\xfaQqK\x19\xb5\xe0\x04\xe5N\xd8wZ\r\x07\xfb\xce\xfe\xb7d\x85\x1c\xb4\xdf\x91w\x0c-@\xb5\x97\xfb\xc8\xbd\n\xa4\xa3\xa6\xfe\xc4\xf5\x83\x99\xf9:\x8d\x84*\x06'
        b"'\x96|3N\xf9\xf7\xbfDe:\x94*K-\x8c\x87w\xd6\x85I\xdc\xa9\xdc\xbb<r\xb6\x05\xd8\xc2Xy\xa7\x91\x1f\xb1\xc9\xdc\xb7\xa2\xbfe\xab\x039\xf4\xc1\x91\xd2\x1a\xef\xacrd)4\xedO\x16U/*\x1a"
        b'~\xeb\xa4\xa2d\x02\x86\xef\xf8\x86f\xd9\xae?\xd18J\xfc\x8b{d\xd3m5Co\x1e\xec\x8d\x8c\xde\xc5\xa8\xce\xb6\xbe\x1a\x85\xb6z}Q\xfdT<\x86i\x94Whk\xd9a\x86\x1a\x81H\xfc=k\\\x83\xde['
        b'\x8f\xa8\x9f\xe6\x01\xdf\xbe\x02\x88@>J\xde\xdcn;\xcaf_\x03\xea\xfa\xc3sI\xf6"\xb3\xad\xc5\xacG\x13\x04zK\x1b\x1a.\xf8\x1bL*\xbe\x85\xc79\xb8\t\x91\xe7p^\xd3\x15\x95\xc5K\xa5\xcd\x94\x08\xff\xbb'
        b'\xcbF\xa5\xca\x1eC\xc5B1\xe0y\x18\x83\x04\xda\x93\x124\xb0?\xbf\x15\xa2\xd7\x9f\xd5\x80\xb0\x06.\xd4\x0f9\xaa\xa4\xde\x83\xa4\xc5\xe6\xdcR\xae/\xec\x9a\xe5\xefd\xdd\xdfX\xa0\xf5\xc7\x02\xa4\xda\x92\xa4\x94\xfd\x9d\xb4'
        b'\xc8-\xf7\xb8\x18\xcc\xee?\'\xd9\xabS\x8d,\x0e\xf2\x9a\xfe~\xe6|\xc0\x8c3\xa41X\xf1\xd0 hu6\x99(\xef\xe7fF"\xb5K\x05@m]\xe4\x87G\xaf\x18\xbc|"\xc4\xf5\x84\xe3Z\x81\n7\x1di'
        b"\x91\x02h\xbd@G\xb9]\xa5\xb6\xfa\xb3n\xc5\xd8\x85\xad6G \xf8\x1d]\xdbp\xf9\x12Z\x16H\xa7\x84\xf4OA\x1e:\x8b\xf6\x02\xec\xd2\x95\x16\x11\x96B\x13K\xca\xcaL\x10\x1et\x8c\xfc\xf9'\x16\x13\xaf-\x0c"
        b'T\x07\x12\xa8\xa4\x891\xc9\x02\xb5\x9a\xd6(d\xcc\x9c\x84\x9b\x86\x1d\xa0\x14L\xd7\xaaB{b\xe8<\xf8\xb5\x1f\xa4\xd1M2N\x0b\xf1\xda-dC\xd7l\xf3\xcb\x96hv:F\x84C\xac\xe1\xb9L\xd8\xf6\x0eh\x8f'
        b"\xd2\xfe\xf1\xd6M\xa1i\x9eZ#xF\xbe\x8a{\x14\xda\xd4\x7fR\xc98\x11\xddr\x11!\xbb\xb1\ts\x9cUT'\x8fr2\x16\xe2$\x8a{,\xbf\xaa\xef\x10\xd5\x14:R\x17\xe6\xa2fT\xfb\xdb\xa2f_\xc2\xf6"
        b"q/\x14\xa3-\xba\xbc\xb4#\xcd\xa7\xf3\x1aR&\xc0\xe3hM\xc0\x01L\xce\x16K\xfc\x1ayn\xc5\xd54\xa0+DC\x1c\xb2\xb5\x8en\x1e}j\x80\xb1\xd4\xe9d\x91\xadD\xe0'\x8d\x12\xeb5\xd8\xc2\xd3?}\x10"
        b'\xe8D\xac\xb2\xb7J\xe4PU\x1f\xce\xe4\xa7\x1f\x18\x19-1{\xff\xc5\x02\xfdx\xdbM5\xd8\x14\x92\x15=\x0f\x8c\xd7t>\xb5\xb4\x98\x82K\xf9\x18|P\xc8\xbf\x8e\xf0\xd3\xb6\x99\x8d\xb6\xb1B\x99\x1a#M#\xc6\x87'
        b'ApM\x1c\xd0.\x81\x99O\x07\x07\x7f(I{\xbd\x1c\xbd\x9d\x12\xf0N\r50\x95\x02\x9bV\x01\xe9B\x8bNf\x8e\x8f?\xed\xc3\xa6\x8dh\x89\x1b\xcd(\xff\xd1\n\xd54,}\xe5\x90\x8e\xa8\xbcU\xc0\xf0\xe3n'
        b'\xa6\t\x81\x82sYz\xbf]e\x91K\x9fakUm\x91l\xc9\xbc\x92\xa7I\x92\n\xc2w\xd2t]\xaf2\x1e(\x80\xae\xfffW\xb9$gM?\xeb\x92\xcc0\x8a\xdf\x19|Z\t\xc5\xbd*\xa8\xf3\xc8\xa7\xf0L'
        b'r51\x17\xb4\xc0\x94\xc2\x84\xef\xa6\xa3\x9e\xfb\x9cR\xe7\xe6\xf0<\xce\x057O2<\x04\xfa\xbb,xp\x89\xd3\xd4&\xe4\xdc1\xff\x12%\x12m\xe8k\x15\xd5\xa3k\xccM3S\xe5\xc8\xbd\xe5\xc9\xd2\x88Y\xf3\xe9'
        b'\xceF#\n\xa9:\xe3R\x82t\x90c5J\x91\x8d\x98\x9e6J"\xf3\xe4\xc6\xe0\xcb@ID\x11!\x1df\xc7{\x0b;\x04\xa79H\x0fz\x18S\xb8j"t\x8cq\xa6\xcc\xf2E\xab\xda\xb3\xac\xa5\xa33k\xe6'
        b"'\xddM\xcd\n\x1d\x08^\xfa\xdc]\x04\x97a\x9a\x1c\x03\t^{\xbd&?\x9d\xe3~\xfc\x05\xcd\x0f\xa1x\xf2gw\xf5\xe6B`\xbfD\xb4(\xba\x91\x94\xc7rx-\x85\x93\xd4\xf3Y_{\x00\xd9)\x10\xf1\xd7@"
        b'\x83:\xbd\xc7P\xb2\xdb%k\xacW\xc7C\xcc\xe6KR<\x98q={m\xcb\xe0\xd5\xf4\xf3]p\xe7\x8b;\x0b\x96v\x8e\xf0\x01D\x82\xdbl\x19\xc6oE\xb1\xadU\xf8\x1892\xc8\x9fS\xa5\xa4\x02\xe9f\xabG'
        b"\x1cZ\xf8\xa0O$Y*/I23\xc8\x10\xfc\x82H\xdbY\x1b\xa5\x1b\x14\x93m\xa5'\xd2a\xbe\xef\x88`ij\xf7 8R\xf4\nb$\xb3n]GZ\xc3\xa8d\x8bi\xed#p\xdc\x02\x00\x1c\r\xd8*b"
        b'\xa5@I\xb8\xfd\xecY!]\xd2\x8a\x82n{\x04\xe8\x06\xd75\xdd\xebYG\xd4\xad-\xafw\x84p\xd61%\xdb\xf5x/\x9e\xf2yfc\x99\xca{\xfc#\x8dd.j\xc2\xba\xbf\x13\xdd\xbf\xae@\xed\xa5\xdbE\x91'
        b'Xp;\xdf\xea\x0fS\x96D\x11J{\xca\x19O\xd0c\xc4\xcb\xfc\x1dLG\x12\xcb[\xca\x08\x1e\xe1q\xc7w\xde\xf3A]\x9f%\xbc\xef\xd2r\x7f\x1f\xa7\xd4\x93Q\xa6\xf2\x86\xe3\x0e\x87\x95D\xb2\xdc&B\xd8~\xc9'
        b'\xf7\x98\xab@\x1c\xf6\x91\xa2\x0fK\xe1nI\xc9$\xcc\xdc\x1c\xdf\x1c\x036\t@\xf0:\xed\xc1\xd6J\xd9\x84\xdb"\xf9\xd2\r\x17\xdb\xd3$$\x9f\xadxBL\xff\x931\xe9:\x81*z\xfa.8=\xafK\xc2 \\'
        b'\x98\xba \xc7.\x13 \x98ze\xfc\x00I\x15\xd6\xef6\xc0\xdb\xacp\xc1\x82<\x97\xff\x99$\x8182\x033\xa3R\xb2\x97H\xfe\x85\x8a\xb1*rVz\x08.\xc8@d\x94\x89)\xad\xfa\x1f\xe0V\x1dT\xaa\xe7\x87'
        b'\xbe)/\xf5\x9c\xf4T\xe5i\r\xaaN\x91\xb0\xda\x0e\r)\x1f\x16]v\x9f\x8af\x80/\xd7\xc9\xda\xd2>\xf7\xa6\xc2\xba\xfe\xad\xefV\x9by({E2z0\xd3\x9c\x1c\x9c!\xd6\x85F0G\xab\xed!\x07\x80c'
        b'\xd6,\xb0\xbaQrb\xfc\xbb:\xc7C\x90j\xb3\xb55\\\x81\x85<P\xaf\x94\xcf\xe4\x80W`\xb7\x0ba\xd0\xe5\x85\x06^\x1d\n\x83DSAf\x04u\xddu\xd4\x05\x81\xb6\x1e\xda\xa8\n\xdf\xa2\xa71\x91mm\x7f'
        b'\x01\xb6\x99\x07+\x9d\xe7\xec\xf7\x12\xae>]g\x82/V\xb0\x1eh\x0f\xda\x94[\x9e\x80\xfd0\x14\x95\x00\'\x0bw\x90\x0e\xc7\x93\xafT\xb9V?I\x8b\xae\xcf\xe3\xbc"\xaa\x04\xb3\x9f\x87\xd8\x94\xb8\xe9\xae\xf0\xf0x '
        b'\x81\x05\x88Y@\x0f/\xfd\xf9z\x08{\x95\xfc\x07\x13b\xcb\x9c\x83\x98\xaa\xe9>\x16\xff\x13\x0f8\xf4\xbec\xb7`~\xc5=\x86T\xeb\xf7\xdb\xad \x0bx\xaaD\x1e\xbe|\xe1\xb6\xb9\x8d\xf0J2lz\xbf\x8eS\x98'
        b"\x92\x03\xc9\xdbaZE\xc3/y*2\xe8\x8c H\x07\xb2`\xd2\xf0\xf4\xb2\x7f\x95'\xb2\xd0\x9d~\xc8(k\xe6\xf1x/\xb0\xac\x14\xe3\x83x\xbe7a\xeb\xdbs\xae\x0b/\xacb\xc0\x9af\xe1\xaa\xf58\xda\x99\x0f"
        b'\xc4\xefP\x86\xb5\x8c\x13\xd5\x18\xfan\xfd0\x19\xa9\xb3!\x82G\xeb\x12\xf0\xcd\xb6\xaej\xd7\xd0\xe6AE\xef\xa1\t\xfe\xf4\xc3pj\xed\x8f\x13\x91\x7f\x9e\xee\x0f\xbe4%m\xf0a\xdb x\xa1\xcd.\x7f\x03L\x1f\x12'
        b'\xd9\x8e\xf2C",\xdd\xbf5tbGn\xbb\xa7\xc1G\xcc\x14LY\xfc\x00\x97\xb7]=U\xb8x\xaf\x9d\xc3N\xa8c\xad`\x11\xb9m\x8c\x97`\xae\xf1W\xde\n\xf48\xca<d\xcf"z3`\x8c\xa4\x96\x9cR'
        b'\xba\x19{\x07>k\xee\x0b\xf7\xf1M\x01\x02u\x89\xfe\xb9\xdc>\x90\x97\xc9\xda\x9b9N\x90\xdb\x9c\xf6\x87\x96\xb1\x9a}\xce\xe7\x81\xae\x9e\xe5\x87\x0c\xe3M%1\x82d\xe1)\xe2NyC\x03b\xca\xa2D\xd9\xdb\xc2\x0c'
        b"\x9a]\x95\x89\xce\x06\x7f7r\x89\xd7\xbf\xe9\xff\xbd\xbb\x0c\x82\x903\xcf\xfa6\xb38B\xb1\xa8\xad\xc6;\xee\x0c\n\x0eKha\x84aP\xa2[\xb9\x90\xd6'\x8f\xb2=\x18Tm\x80\xe9\x01\xd6R\xdcG\xc9\xc8\xac\xff"
        b'\xf0\xd0\xe0\xdb\x04H\xf0\xb8\xde?DkW\x08/Xd\xb1)\xd0e]\x83\xfc\x06(\xc1Y\x8f\x9cTI^BWUfA\xfdw\xd8\xa0V\xff\x13\xb9\xc4\x85\xe0\xd5\x15=\xf2\xe2\xa0\xc26G\xa6$!\xeaq\xde'
        b"\x96\x9f\xbd\xf1\xa8\xe4\xc6\n\xf0\x8c\x16\x1d\x0e\xabu\x9fV\x1d\xb8@\xe1\xf64;_\xb0\x83d\xb3\x17\xa6\x11'N\x9d\x02\xb5\xecA\x81N\xd5\x19\xd9\x1c'\xbe\xd3\xa2`@\x99qiVy\xc9Xf\xb8\x0cs\xc5\x93"
        b"\x9c_.jr\xbd\n wM\x0c4\xf5\x83HUx\xa8\x8b\xbf\xe4w\x97Iy\xea\x89k\xc5\xc5A\x1c\x14\x08\x9b\xa8\xb8\xdd\xab\xb7'\xea\x89[\xdc\xab\xdb\x0e\xe9\xb8\xa1\xb8\xb7\x01\x95\xbeA\x81\xf6\xdd\x969\xbb\x97"
        b'\xc4"\xd9\xf0C\x0ce\x90`\x95\xbb\x83\xa8\xa1\xae\xa1/\xe0\x9f\x8bm\xfcHy\xa2\x06\x1fz\x85(x\xce\xd7?\xcb\xf9>\x83%\xa2!@\xf5\x1cj\x8eS\xc5\xd9\xd6tU\x8c6\n\x16\x97(\xe4\xd9\xfc\xbe%\x8b'
        b'O\xd2\x0c\x1c\x03\x93\xf4\xa1\x98\x08\xe8\n\xee\xab\xce;\x84\x03Hw]ZN\x86{\xe0P\xed\x92\xbai\xc6\xf9"\x95Q\x1dPN\xa3\xeb\xfb\r\x84\xd7\xddU\xe3\ti\x93q\x04)\x01\x03bE\x1b.\x95\x06q6'
        b'\xd3\x95\xbe\x8e\x02\xdc\x0c;\xa5ep\xd9\xe0%\x032\xa2L\xac\th0\x83_\xefD\xa9\x1f\x8e\xc3\xd2\xde\xf6\x91S\xcd\xbb\x0e\xaf\x02\xc9\xb14\xb7gZ\xb7^|t\xa5\t\x0e\xe5\xde-s\x0b\x1f\xbc\xaa\xef\xcb\xc4'
        b'\xd8p\xc9\x03\x83\xe7\x0b\x92\xf4\xf2\xf9\xb0 /h\x8b"\xe8<\xb0\xd159\xedJ\xc6\xb7\x0f\xe8O\xfe\xd8\rKU\x19\x9cV\xe9\xd5\xc4+\x9b\xcc\xc0\xae\x99\x18\xed\x86{\xbdz\x8f\xea3\xe4M\xd1\xa9\x84\xfdW1'
        b'`\xcb\xfd\xa03\x98\xa4\xa6\x8d\xd2lD\xc3\xf2\x19\xf7~\xb0\xeb\x87\xf0Pz\x8a\xe903*\x8f\xe1C&B\x83p\x99\xff\xa7\x9f\xa2~\xa6:\xe5\xc3\xc8a\xa1{9\x91>@\x8e\xaa\xb2m\x1e\xc7\x984;\t\x9e'
        b'$\xbc\x1d\x8f\x98\xb6\xcd\xc9\x98\x18Zg\x12Ep\x01\xf9R\xc3"xd\xcc?\r\x9ep`\x08Y/\\1\x1f\xd3\xc6\xd6`\xf6\x1e\xbb\x15\xaf\xd78h\xd5]\x022\x8a\x9c\xa0\x05\x93[\xafz\xe7\x16aV\x9c\xe3'
        b'\xc8\x80!Q\x7f\x0b\x81\xc0.\xc6\x82*\r\xe1\xc2\xc9T\x13\xc8C\rOuEz\x0er\xff\xda\xf8\xc0\xc2\xc4\xb6}/\xe2\x89~\x06B\xa4M\xfd\xfc\xf1\xe9\x1b\xcc\x05m(Z\xf9\xdf\x97\x8a\xce\xd7\x86!\xf5\xb2\xef'
        b'\x13M\x14\xd4\xae\xc9\xbe?\xd8\xd2\xa6|\xe3^\xf5x\x11r?Cl\xda\x9f\xd3<\xcd\xb7\xa8\xb9\xc4Y\x1a\xaa\xb31\xd88pvF\x0e\xa3f~s\x93\x89D\xbb\xf3B\x9a\x94Yk`\xafQLf\xfa\x14\xa7\x82'
        b'\x17u\x82FE?O\x1e\xb9\xf1 \xcd\xef4r\x8b\x18@\xe7\xc1\xa55\xe1\xc1_F<+\xd8\xee\x84\x10\t\xb1\x97E\xbbeZ\xd2\xf8\xa8H\x82\xf4\xb7\x9dd\x89o\xa2\x98SI\xd2T\xfde\x8a\x8ctL\x15\x94'
        b'\xe4Z\xbdp\xe8\x07L\x98\xdf\xfe\xdb7\xcb\xd1\x8eA\xd0\x97\x12\xd4H\x8a\xf3CK\xa0\x00h\xd3\xcf\x9f\x83\xf6H\xa3\x14:y\xea\xb5\x06\x17.W\x07\xd4^V\x8anT\xf1\xef\x9a6\xd2g\xbf~J\x91\x7fQ\xfa'
        b'\x9f\x08|\xbc \xbc\x96v\xed-.\xb2`\x85\xf2X\xb0\x90\x1fi\xc2&\xe0\x12\x13M\\\x17\xc2H\xaf\xa2k\x81\xe5\x00\r],C\xa5\xde\xa4\xdf\r|\xe1\x14\x10\x9b\xefT\xdd\xd4\x9e\xe3\x05S\x9e\x13]_\x1d\xf8'
        b')a\x10\x9e^\xcf\x8b\x19\x92\xfds>K\xb2\x16f\xba\xaf\xc0m\x1b\x85(s\xe1\xd3a\x0e\xb3\x07\xee\xdci\xadJ\x9e\x81\xcdH\xff\xde\x06\x93\x7f\xc5$\xba\x04\xa0\x16\xbf8\xb7X\xd0YI\xaa\xc6%S\xee|_'
        b"\x82\xadT\x1f'\x1a\x16V\x9c\xafB\xe6\xf3\xc2\xb9\xdc\xa9\xc6T\x1c\xc8\x85\x7f\x84D\x10a>bi\xf8\xd8\x04;\x0b\xc2\xe0\xcaE\x89\xa9\xc0\xc4\x9dU\r\x94D+{\x98\xdd7F8\x87b\x11\xbet\xdd\x1c\xffB"
        b'\xd6\xc7\xd9\xa3E\xcd\xe9g\xee#r\x83}q2;\xd9(8\xa8\xa5c\x135\x7f\xf8\xeb]\xa42e\xbd\xc0\xbc\xf1\xbc!:0\x94\xab\x0eCrH\xa3\xfe\x81\xc1\xd3>\xce\xa7\xf8\xd5\xc9\xdb\x11\xef+\xd3\x0f\xb4F'
        b'\x16\xd8\xab;\xa5\xd4\x89sU\x98\xb9\x1fd\r\xa2\x08\xd8\xb4l\xf4\xd1\xbe\xe6\xee\x0c\xc5%\x8e\x9d\xbaVG\x95\x9b\x88K\xa8F37\xe3\\\x0e\xab\xb7)8|\xf4\x91\x95y\x97\x03leo~6 \x1fM\x97\xf1'
        b'OL\x89\x9aT\x87B\xae\xdbW\xbaL\x9f\xf3\xdbJ!\xc8\xeb\xe8\xdb\x1b\xa7\xc5\xd8\xde\xb0\xbe6*\xb8\x0c\x0c\xf1\x08W\xa6!\xaa\x80SbN\xc3j\xdaJH\x7f\x86\xdak+\x1b\xc6\x11I>Z\xc4\x04HZ\xeb'
        b'\xb3&ba\xec\xd0\xb6y/\x12\x18\x00w\xbc\xe0\x08\x19\xd2\xbdx*-\x07k#\xe3\xa4\xc59\xdc=\xa5\xfc\xf9i\xdd\xc7\xd8\x86>2|,\x04`iTm\x80\x0e)\xb3\xccUV\x80\xb6\x7f\xa9U4\xbf\x11\xa0'
        b'\x10\x9d\xce;\xd0X\x0eFnb\x1c\x08L\xe0-\x93\xc6p-\x9bA\t\xc2\x82\xee\x07 \xd0s\xa8\xcb\x19?\xda\xb8\xc6\x9e\xacc\xf0>a\xda|4)\xcb\xbe\xd5\t\xe3hA\xeb\r\xf3Q\xb9\x9bf\xb0\x03\x92\x1c'
        b'\x1e\xb6\x12\xbc\x9a\x8a\x89\x92}!\x98i{P\xcb)\xc5AX,r}\t\x97\xb7\x85\xe5\x17g`yv\xfey\xac\x00|\xde\x05\x8f\x8c\xdc\x16\xd5\n\xe8n\xe9\xc6\x8b\x84\xf0A\x0c\xbb\x10\xa6\xac]\x8f\x19\xba1\t'
        b'\x93,\xbe}\xf5qVK\xa4L=\xdb3\xdcT\xa6^8\x04\x9c\x824\xbe\x99y\x00\xf3I\x1e\xc1k\xc8\xe2h~\xe3XX\x84\x1eb\x9c\xe3R)``\xeeq\xb3^[&\x86aFXx\x9aA\x9e\xd7\x87\xcd'
        b'V\xb4\x0c\x15\xb7\n\xbazN\xa7\x9bmO\xd5S\x92H\xb7C*\xc7cGQ\xfb\x01*\xe7yjRa\xc7[\xd1\xcd\xbf\xb1\xe1\xdaIj\x90\xef5X\x8a\xc3\x9f\x0f\xe1zD\xf2\xcd\xfe\x89P\xf4\xe0sO\x1c\xe8'
        b"%\xf9\xcb\x1a\x99\x86\x0cy\x1er~\xee7\x18\xb8\xad\xbd\xa3\x87\xd1&\xe8'\x1e\xacy\x00\x85\x04\x8b\x85=\x0fQ&1\xb6}\xc8\xf9\xa5\x1f\xf3\xeb\xc7A\xd2\xe5^\x0f\x84\x82\xd0\x12\xdf0]\xf4\xb8\x98b|\n\xb3"
        b'\xa7!(/b \x84\x1fH\x9cg2\x19\xd8\x08\x1e\xf9 \n\x9eo\x8erS\xf4L\xf8&F\x9eD\xa2\x8ce\xdc%\x18\r\xdf2\xba\xbd\x85\x97?\xcb\xff\x12\x0ec\xa5\xadM\x83\x9c]\xe8h\xd5\xc4\xcc\xbc\xf4\xc7'
        b'\xba\x98J\x80\xc8\xa1\x12"\xf4\xb6\x7f\xb4\x9au\xc0c \x8c,\xe6\xedX/\x80\xd5\xe9\x9eM\x99\xdb/t-\x85\xf8\xfe\x89^\x7f\xffSl\xbf\x98iD\x95\x95\xa2(\x89H\xa1\x9b\xc6^$\xe9\xb8\xf9\xc9Q\xb5\x8e'
        b'O]\xac?\x04<\x8b\xbf\x89!o,2\xde\xb7\xb4\xc9\xc4\x889\x8c<\x90\\\x85\xd1\xbc\xed\xe2\xc2f\xe3\x96e\x99\xa9f)kb\xa3\x1c\x86\xfa\xe34u\x9dE\x84\xa87\xc6\xc3\xe2\xfc\xa0L\r\x01?B\x14z'
        b'\x06\xf9j\x07\x84\x80)R>,d\xfc\xa1%\x83\x15\x1d$\x10BM\xc7)\t\x0c\xbdi0)\xdf\xc5\xcb\xa3\x06\rKg\xbf1G$ \xd8\xb21\xf9\xd7R\x0c\xf2\x16\xe6\xd2\xa9R\x93\xf1\x86@Kd\xf9y\xc4'
        b"E\xf3*@&h\x9f\x80\xeaW'\x98F\xde\x98O\x926\xa8/\xb6}\xdeRD\xfd\x90E\xab\xe0\xdbe\xb3DN\xda\xde\xaf}\x11aR?\xa0~[\xf71kE\x14\xdev\\\xc5i\x99![\xc4\x08)\x9dK"
        b'\x160p\xf6u \x1dB4\xff\xee\xe7\xd1b\x93\xb8\xac\rN\x91\x10;(\x08jz\x19\x0f8\xde{\xa79\xcb\xb9\xcf\x95\x85\x10\xedU\xc0\xfc\xdd\xf9K\xe56\xf6\xb0\xfa\x82tW\xb95-\xa4\xe8k\x8e:\xf2\r'
        b'\x0bq\x829\xfb\xf5\x0c\x83\xffG\xe2,\x19\xc6y\xd1\x94\x95\xeb\xa9\xff&1\xdd\xb46\x1d"t}ZS\xe4\x19\xf0\xdd\xa6\xfb6&{\xc3\x88\xcc\x13\xf4h\xc6\x99L\xa6`\xe9%\\\xb4\x0b3\xae\x80\xa9\xb1#\x94'
        b'\xdfn \xf1\xba\xd3\xd4\x98Zp\\f\xc6\x94\x1d\x1c\x19fJX\xb2M\xcb\xf1\xe7\xd0d\x02\xc4T"p]c\xc0\x05\x19(\xce\xfcB\xa9\xb1\x1c$\x96\xd8\xd6g\x94\xb3\xe3\xda\xc7\xf78\x19sNp\xf7\xf1\xfay'
        b'\xa6#T\xa7\xff7\xf2\x8c(s.\xb1./\x18K\xed\x9c\x8c\x19~\x10\xbbT\xa1&\x97X|i\xb0\xec\xa1\\\xe4\xdfB\x14q\x9a\xeddZ\x84?\x8f\xf7\xd2q\xb2\xd4`\x81\x93\x90 \xbb"{\x16g\xe8\x91\xc8'
        b'\xb4\x7fX\x9f\xfbF\xcf\xe5\xe5C\xd1\xda\xf3\xa6\xe9\xf7NVg\xc4tN\xc1\x1b\x8c\xa96\x93;\xeb\xe3\xff%\x7f\xbc\x03\xaaO\xd7\x93\x12F\xdadN\xb4`\xba\xcf\xd6\x9c\xf7Py\x91\x07<d\x8f\xd9i\x82_\x80'
        b'0)\x1a\xecH\x8b\xa4\x15\x00\xe0W\xd5\x1a:\xc7 \xff\xd0\xbe\xde1\x88\x01\xb1\xd1\xc7*Y<K\xde\xd8\x0e\xf1\xdc\xcbS\x12\xbe\x1b6"J\xa2\xa2QU\x8d@\x1e\xd4\xafXF\x8b\xec\xe8\xcd\xf1\xe4\n\xc5\xb8U'
        b'\xeaG\xf6Xb5:\xc4\xf8\x91L\xba\xb5z\xb0\xa1\xf9\x92\x9b\xba\xf0\x91N\x8e\xe34\xba\x89L\x14\xe5W-\xb6\xbd\xc49\x82\xb1\x8f\x0e9n\xe2q4AE\x9b\x88\x17\x96\xde\xa5{\xde\x04\xfc\x9b\xdf\xc7[P\xc4'
        b'\x1f\x18Ve\xc7B\xfa\x888\xa2\xb4\xf8\xe1\x88\xbf\xe3\xc8\x0cf3\xc58\x9bI\x05D\xb5\xf5\xd3c\xd9\xbc\x8b\x9b\x16\xf4\xae+N\xca\x8b&\xa3\x8d\x1c%e{l,\x99\xa8\xdc<\x90\xe9\x85\x0f\xd3\x19\x1e\xb1\xc0\xa2'
        b'u\xa6\x1f\nQ9\xd5\xf3T`\x8c\xca\xdaxd\xa6U"\xf8\xac\x08\xb3I\x10\xabO\xa3\xc6\x8d\x06K\x0e/\xa6\x160~! \xffY\xd93y+\xe94\n\xf7_\xd2Z\xc4\xf0!-pE+\xef`Qs\x9f'
        b'\xb8\xb1F\xc7\xc4\xf4\x8c\x17}\xe5\x96\x8b\xa2\x06\xfd_p!\x98\xd4 \xf4\xd3c\x84y\xfd\xd7\x08x\xd75~\xe0p2-r\x05\xd4)\x001v\xe1\x91\x88q\xd5\x86zy\xc0\xdf6\xd0\x1fw4D\x9aj\xd70'
        b'\x90+\x9b\xcfR\xa6\xda\x00jVO\x8b\xa6M\x08\xb6\x14\xafP\xdf:\x82\xd0\xae\xa0\xb2\x17\xea\xb9\x7fX\xce1\x9d\x1e\xa1\x1d\x95\x12Z\r\x120\x07\x98\x07i\x05\xf5\xfe\xbb\xa0\xae\x8f\x1c*\xfa\xdcb\xe7\x99\xb1S$'
        b'B\x0c.\xfb \\g\xb6\xd3O1J\x9d\xa7\x0b\xee\t\x9c\xbb\x98\x01\xdd\xae5\xc5\x903\xa9\x9cQ\xa4\xb36\x98\x12/\xe7\x0f\rbG:\\\x8dv_k\xa8\x03\xf8\xe0e\xea\xc2\x91\x9a\xa7O\x96H\x85*:"'
        b"\xdc\xbd\x9fa\xa8\xd1\xe8c\x03:\x9d\xa5\x8a\xc9\xda\xd2\xc1\xbcv\xc4\xf4\xb2\\\xd06j2\xb7UZ\xfdX9\xd9\x97\xd3>\xf3\xd8\x01'\xc9\xab]\xf3\\\rM\xb1\x19\xed\xd0\xab?o\xda]\x12am\xf1\xcc\xd7o"
        b'\xb0\xbb\x95\xe0\xfdPT\n\x02\xc6\x8e\xe7\x87qC\xbe\x80\t\xed\xa8\x96\xa3\x13:\n\xaa\xcc\xad\xd5\xebj\x9e\x1e\x8c\xdc\xc3x\x02\x19\xce\x16f\xa4\xee\xc1\xaf\xa9\x1b\xfas\x04\xb1i\xffT\x8e\xbb\xdf\xfb\x85bd\xa1n'
        b"\x92Z\x9f3J@\x9c'=\xb7\x81\xebN\xf8\xd0\xab2\x00\xc6\xe1\x06\x86%\xad\x960\x94\xc4\xa0\xce\xb6(3\xe5\n2\xbbfz\x0c\xc1\xa1\xae\xec\xe8\xea\x01\xb9{\xba\x1b\x173\xcb\x0ec\xbd\xee\x86}\xf3\x13\xf1\x0b"
        b'f\xe8\xa3(wo\x89gb\x90|\x0b\x86\xd4)\x83]\xef\xa5P.a\xdd$\x08\xe3Bi\xa9)\x1e4oo\t<Ru\xcdg@pub\xcb\x8b\xa6H\xb6N\xa5\xea\xa6\xa8\x1eL\xd8*\xc7\x86\x95\xb0d\xd3'
        b'5\n\xb9\x9c\xdc\x03S?\x9e\xc3\xa9\xb7\x8e\x0b\x96!8\x8bZ}\x99\xe0\x81`W`\x1aKe\xe1\xe8*\x8f\x8f\x865\xdcdn\x1df\x95\xa8\x04\x8b=\xfaHc&\xcc7\xef\xea\xd3\x9e)\xd4G\xd4\xcf\xa1\xbe_'
        b'-\xf6\x13\xc9X\xa9bb`B\xc6\x9f\xdd_\xb0\x7f(\x87\x11\x12\xf3W\x8e\xa6\x03\x17\xba\xb1\xf7!%\x9f8\xe7L\x0c\xf1\xd9\xe3\x91\xc8\x97\xed\xd2R\x82\t\xe8x\xd4\xaf\x11|\xd0\r\xabJ/\xe7\xf0V\xd6\x96\x7f'
        b'1S\xdf\x96\xe9\xe0J\x98=P;P\xed\xf2<\xa8\xdci\xeb/\xcc\xc5\x03\x8e1\x05\x18\x00`bO`@g\xae\xb8o^w2\xd8!\xd2\x8a\x8b\xcd\xd6Ih\x0bl}p\x85%\xe1\xa5\x01Y\xc4\xaayDy'
        b'\xadH\x12\xce\x12D\x1aF\x07d \xd3U\x0c\xc5\xbb\x87\x07\xe6\xe7\xff\xa4\x9e\xbdW\x9c\xcd\x90n$\xaf\xb1\xda\x8d\x85\xf0=\x8e\xfbs]S>a\xf9\x86\x97\no\x8c\x0c!\x03\x04\xa7\x07\x92M\xfe\x16\x93b\xcc\xb3'
        b'\xe9|\xf4E\x9f\xb3\xd6\xadA\xe4\xc2\x9b\t\xf6\x11\xb3\x1e\xbfg\x85\xdf\xd5\x8e\xc0\x0fH\xc9-\x03\xdb\xb9R\xc3\x97A\x80\xdb^\x07\xbc\x1f\x92w\xc1O\xc7\xb6\x90t\xc0\x89\x92i\x92\xbc\x16\x04w\xd9\x8bG\x95\xddc'
        b'\xb6!\xbaW\xe3\xf7\xb0\xc7E\x81\xa6\xf5\xd1\xc2\x0f\xa2NYy\xf9-\x9f\x1bl&\x80\xf8\xa5\n;\xd7F\x0e~\xd7\xbfR\xe2\x05()s\xf7\xbc$\xe5\xb4\x9a\x8b\xcbKY\x94\xac`K\xba\xe9\xa2\x12&\x85\xe5\xa8'
        b'\r\x83\x8c(?\xfe\xea\xfc\x97\x14\xea\x1f\x9b\xd7\xe8\xcbC\xaa\x1b\x9e\x1b2aM\xf7\x15\xabf\xdf\xd7heB\x9biz\x9bV\n)\xed\xc4\xed\x148\x95\xca\xd9\x12\x7f\xcd\x1e\xe7\x82P\xab\xb3c744A*\xbb'
        b'\x96$\xd1T\xb8\xec$\xa6\x8a5\x9a\xa5\xb6\x8d\t\x98\xfdz\x03k\xcd\xcd\xf3/\x82(`N\xe9\x8c\xaevA \xec\xeb=\xe2\x0f\xf8IM`\x1f\xcb\xe4\xadAz5>\xfd\x8c%m\x81\x92];\x1b!`\xcf\xc2'
        b'6\xc3\xcbY\x8c!-\xef\xb6\xdf\xa5[\xad\xb7\xdb.\xa7l\xba\x9f\xb3g7=\xac\x9b\xb0+\x13\x86`\x9b\xb3\xea\xdf\x8b\x95IFY\xb3\x93M\xcbb\xf8->\x1d\xb8t\x92>\x9c\x02h\x15\x06KK9\xa2\xdcx'
        b'l\x83?\xdd#\xd4\t\xce\xc0 U\xb8~\xe6]2\xa9\x0f\xda\x9a%\xa51\xbf\x07\x18k\x1b\xcbr/w\x1a9\xe5=\xb4"R[\xd2\xd4q\x0er\xc2c2\xa3nT9\xbb\x93\x81\x7f\xe0\xe6\x91\xe6\xaf5 z'
        b'\xfcKe\xf6\xdb\xcb\xf8\xf6u\x17=~z\x0f\xbe?\xc6\xc5p#\x9fS\xb2\xe6\xd3\x1bo\x8d9\xf5\xe6\\O\xe7tt\xe7\xa7\xa6\x040\xa9\xc4\xf3\x114M\x97\xd4\xeexI"\xa8\xeeq\xf4\xd7\xcd\x01r\x1c\xd0\x11'
        b'\x12\xa7\x00M\x1b\x01\x8a\xd2\xec\x19\xe6\x1e\x85W$Lv\xbb5\xaa\x93s\xaeeK?\xfflN)\x04\xda\x07runtimer\x03\x00\x00\x00\xda\x08__name__\xda\x08__file_'
        b'_\xa9\x00\xf3\x00\x00\x00\x00\xfa\x16<frozen fintech.swift>\xda\x08<module>r\n\x00\x00\x00\x01\x00\x00\x00s\x1d\x00\x00\x00\xf0\x03\x01\x01\x01\xe5\x00 '
        b'\xd9\x00\x0b\x88H\x90h\xf0\x00\x00!kd\r\xf5\x00\x00\x01ld\rr\x08\x00\x00\x00'
    ))
